// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_ALL_LOW_RD_IS_RN_IN_IT_BLOCK_BIC_T32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_ALL_LOW_RD_IS_RN_IN_IT_BLOCK_BIC_T32_H_

const byte kInstruction_bic_gt_r3_r3_r0[] = {
  0xc8, 0xbf, 0x83, 0x43 // It gt; bic gt r3 r3 r0
};
const byte kInstruction_bic_ge_r6_r6_r1[] = {
  0xa8, 0xbf, 0x8e, 0x43 // It ge; bic ge r6 r6 r1
};
const byte kInstruction_bic_gt_r7_r7_r1[] = {
  0xc8, 0xbf, 0x8f, 0x43 // It gt; bic gt r7 r7 r1
};
const byte kInstruction_bic_gt_r2_r2_r0[] = {
  0xc8, 0xbf, 0x82, 0x43 // It gt; bic gt r2 r2 r0
};
const byte kInstruction_bic_eq_r5_r5_r2[] = {
  0x08, 0xbf, 0x95, 0x43 // It eq; bic eq r5 r5 r2
};
const byte kInstruction_bic_gt_r0_r0_r0[] = {
  0xc8, 0xbf, 0x80, 0x43 // It gt; bic gt r0 r0 r0
};
const byte kInstruction_bic_lt_r0_r0_r4[] = {
  0xb8, 0xbf, 0xa0, 0x43 // It lt; bic lt r0 r0 r4
};
const byte kInstruction_bic_hi_r6_r6_r3[] = {
  0x88, 0xbf, 0x9e, 0x43 // It hi; bic hi r6 r6 r3
};
const byte kInstruction_bic_ge_r7_r7_r6[] = {
  0xa8, 0xbf, 0xb7, 0x43 // It ge; bic ge r7 r7 r6
};
const byte kInstruction_bic_eq_r5_r5_r5[] = {
  0x08, 0xbf, 0xad, 0x43 // It eq; bic eq r5 r5 r5
};
const byte kInstruction_bic_cc_r1_r1_r0[] = {
  0x38, 0xbf, 0x81, 0x43 // It cc; bic cc r1 r1 r0
};
const byte kInstruction_bic_cc_r1_r1_r1[] = {
  0x38, 0xbf, 0x89, 0x43 // It cc; bic cc r1 r1 r1
};
const byte kInstruction_bic_cc_r4_r4_r3[] = {
  0x38, 0xbf, 0x9c, 0x43 // It cc; bic cc r4 r4 r3
};
const byte kInstruction_bic_mi_r5_r5_r3[] = {
  0x48, 0xbf, 0x9d, 0x43 // It mi; bic mi r5 r5 r3
};
const byte kInstruction_bic_cs_r3_r3_r0[] = {
  0x28, 0xbf, 0x83, 0x43 // It cs; bic cs r3 r3 r0
};
const byte kInstruction_bic_pl_r0_r0_r6[] = {
  0x58, 0xbf, 0xb0, 0x43 // It pl; bic pl r0 r0 r6
};
const byte kInstruction_bic_cc_r4_r4_r4[] = {
  0x38, 0xbf, 0xa4, 0x43 // It cc; bic cc r4 r4 r4
};
const byte kInstruction_bic_cc_r3_r3_r6[] = {
  0x38, 0xbf, 0xb3, 0x43 // It cc; bic cc r3 r3 r6
};
const byte kInstruction_bic_hi_r7_r7_r3[] = {
  0x88, 0xbf, 0x9f, 0x43 // It hi; bic hi r7 r7 r3
};
const byte kInstruction_bic_vs_r7_r7_r5[] = {
  0x68, 0xbf, 0xaf, 0x43 // It vs; bic vs r7 r7 r5
};
const byte kInstruction_bic_le_r2_r2_r7[] = {
  0xd8, 0xbf, 0xba, 0x43 // It le; bic le r2 r2 r7
};
const byte kInstruction_bic_le_r5_r5_r3[] = {
  0xd8, 0xbf, 0x9d, 0x43 // It le; bic le r5 r5 r3
};
const byte kInstruction_bic_vs_r1_r1_r5[] = {
  0x68, 0xbf, 0xa9, 0x43 // It vs; bic vs r1 r1 r5
};
const byte kInstruction_bic_vs_r7_r7_r3[] = {
  0x68, 0xbf, 0x9f, 0x43 // It vs; bic vs r7 r7 r3
};
const byte kInstruction_bic_cc_r0_r0_r3[] = {
  0x38, 0xbf, 0x98, 0x43 // It cc; bic cc r0 r0 r3
};
const byte kInstruction_bic_cc_r2_r2_r5[] = {
  0x38, 0xbf, 0xaa, 0x43 // It cc; bic cc r2 r2 r5
};
const byte kInstruction_bic_gt_r7_r7_r7[] = {
  0xc8, 0xbf, 0xbf, 0x43 // It gt; bic gt r7 r7 r7
};
const byte kInstruction_bic_ls_r7_r7_r2[] = {
  0x98, 0xbf, 0x97, 0x43 // It ls; bic ls r7 r7 r2
};
const byte kInstruction_bic_lt_r0_r0_r2[] = {
  0xb8, 0xbf, 0x90, 0x43 // It lt; bic lt r0 r0 r2
};
const byte kInstruction_bic_ne_r3_r3_r4[] = {
  0x18, 0xbf, 0xa3, 0x43 // It ne; bic ne r3 r3 r4
};
const byte kInstruction_bic_ge_r3_r3_r7[] = {
  0xa8, 0xbf, 0xbb, 0x43 // It ge; bic ge r3 r3 r7
};
const byte kInstruction_bic_hi_r5_r5_r7[] = {
  0x88, 0xbf, 0xbd, 0x43 // It hi; bic hi r5 r5 r7
};
const byte kInstruction_bic_vc_r0_r0_r3[] = {
  0x78, 0xbf, 0x98, 0x43 // It vc; bic vc r0 r0 r3
};
const byte kInstruction_bic_cc_r7_r7_r3[] = {
  0x38, 0xbf, 0x9f, 0x43 // It cc; bic cc r7 r7 r3
};
const byte kInstruction_bic_ls_r5_r5_r4[] = {
  0x98, 0xbf, 0xa5, 0x43 // It ls; bic ls r5 r5 r4
};
const byte kInstruction_bic_vc_r0_r0_r1[] = {
  0x78, 0xbf, 0x88, 0x43 // It vc; bic vc r0 r0 r1
};
const byte kInstruction_bic_hi_r0_r0_r6[] = {
  0x88, 0xbf, 0xb0, 0x43 // It hi; bic hi r0 r0 r6
};
const byte kInstruction_bic_mi_r7_r7_r3[] = {
  0x48, 0xbf, 0x9f, 0x43 // It mi; bic mi r7 r7 r3
};
const byte kInstruction_bic_cc_r7_r7_r4[] = {
  0x38, 0xbf, 0xa7, 0x43 // It cc; bic cc r7 r7 r4
};
const byte kInstruction_bic_pl_r0_r0_r3[] = {
  0x58, 0xbf, 0x98, 0x43 // It pl; bic pl r0 r0 r3
};
const byte kInstruction_bic_ls_r5_r5_r0[] = {
  0x98, 0xbf, 0x85, 0x43 // It ls; bic ls r5 r5 r0
};
const byte kInstruction_bic_ls_r2_r2_r5[] = {
  0x98, 0xbf, 0xaa, 0x43 // It ls; bic ls r2 r2 r5
};
const byte kInstruction_bic_ls_r0_r0_r3[] = {
  0x98, 0xbf, 0x98, 0x43 // It ls; bic ls r0 r0 r3
};
const byte kInstruction_bic_pl_r5_r5_r1[] = {
  0x58, 0xbf, 0x8d, 0x43 // It pl; bic pl r5 r5 r1
};
const byte kInstruction_bic_mi_r1_r1_r1[] = {
  0x48, 0xbf, 0x89, 0x43 // It mi; bic mi r1 r1 r1
};
const byte kInstruction_bic_ls_r5_r5_r3[] = {
  0x98, 0xbf, 0x9d, 0x43 // It ls; bic ls r5 r5 r3
};
const byte kInstruction_bic_gt_r2_r2_r7[] = {
  0xc8, 0xbf, 0xba, 0x43 // It gt; bic gt r2 r2 r7
};
const byte kInstruction_bic_ge_r2_r2_r5[] = {
  0xa8, 0xbf, 0xaa, 0x43 // It ge; bic ge r2 r2 r5
};
const byte kInstruction_bic_gt_r7_r7_r3[] = {
  0xc8, 0xbf, 0x9f, 0x43 // It gt; bic gt r7 r7 r3
};
const byte kInstruction_bic_vs_r6_r6_r3[] = {
  0x68, 0xbf, 0x9e, 0x43 // It vs; bic vs r6 r6 r3
};
const byte kInstruction_bic_cc_r1_r1_r7[] = {
  0x38, 0xbf, 0xb9, 0x43 // It cc; bic cc r1 r1 r7
};
const byte kInstruction_bic_ls_r0_r0_r1[] = {
  0x98, 0xbf, 0x88, 0x43 // It ls; bic ls r0 r0 r1
};
const byte kInstruction_bic_gt_r3_r3_r1[] = {
  0xc8, 0xbf, 0x8b, 0x43 // It gt; bic gt r3 r3 r1
};
const byte kInstruction_bic_cs_r7_r7_r3[] = {
  0x28, 0xbf, 0x9f, 0x43 // It cs; bic cs r7 r7 r3
};
const byte kInstruction_bic_gt_r5_r5_r3[] = {
  0xc8, 0xbf, 0x9d, 0x43 // It gt; bic gt r5 r5 r3
};
const byte kInstruction_bic_le_r2_r2_r5[] = {
  0xd8, 0xbf, 0xaa, 0x43 // It le; bic le r2 r2 r5
};
const byte kInstruction_bic_ne_r1_r1_r0[] = {
  0x18, 0xbf, 0x81, 0x43 // It ne; bic ne r1 r1 r0
};
const byte kInstruction_bic_ne_r7_r7_r7[] = {
  0x18, 0xbf, 0xbf, 0x43 // It ne; bic ne r7 r7 r7
};
const byte kInstruction_bic_lt_r2_r2_r1[] = {
  0xb8, 0xbf, 0x8a, 0x43 // It lt; bic lt r2 r2 r1
};
const byte kInstruction_bic_vs_r3_r3_r1[] = {
  0x68, 0xbf, 0x8b, 0x43 // It vs; bic vs r3 r3 r1
};
const byte kInstruction_bic_gt_r7_r7_r5[] = {
  0xc8, 0xbf, 0xaf, 0x43 // It gt; bic gt r7 r7 r5
};
const byte kInstruction_bic_ls_r6_r6_r1[] = {
  0x98, 0xbf, 0x8e, 0x43 // It ls; bic ls r6 r6 r1
};
const byte kInstruction_bic_pl_r7_r7_r4[] = {
  0x58, 0xbf, 0xa7, 0x43 // It pl; bic pl r7 r7 r4
};
const byte kInstruction_bic_ls_r6_r6_r7[] = {
  0x98, 0xbf, 0xbe, 0x43 // It ls; bic ls r6 r6 r7
};
const byte kInstruction_bic_eq_r5_r5_r3[] = {
  0x08, 0xbf, 0x9d, 0x43 // It eq; bic eq r5 r5 r3
};
const byte kInstruction_bic_lt_r2_r2_r7[] = {
  0xb8, 0xbf, 0xba, 0x43 // It lt; bic lt r2 r2 r7
};
const byte kInstruction_bic_pl_r7_r7_r6[] = {
  0x58, 0xbf, 0xb7, 0x43 // It pl; bic pl r7 r7 r6
};
const byte kInstruction_bic_cs_r1_r1_r6[] = {
  0x28, 0xbf, 0xb1, 0x43 // It cs; bic cs r1 r1 r6
};
const byte kInstruction_bic_cs_r0_r0_r3[] = {
  0x28, 0xbf, 0x98, 0x43 // It cs; bic cs r0 r0 r3
};
const byte kInstruction_bic_mi_r3_r3_r2[] = {
  0x48, 0xbf, 0x93, 0x43 // It mi; bic mi r3 r3 r2
};
const byte kInstruction_bic_eq_r4_r4_r5[] = {
  0x08, 0xbf, 0xac, 0x43 // It eq; bic eq r4 r4 r5
};
const byte kInstruction_bic_cs_r3_r3_r4[] = {
  0x28, 0xbf, 0xa3, 0x43 // It cs; bic cs r3 r3 r4
};
const byte kInstruction_bic_ls_r7_r7_r6[] = {
  0x98, 0xbf, 0xb7, 0x43 // It ls; bic ls r7 r7 r6
};
const byte kInstruction_bic_vs_r0_r0_r7[] = {
  0x68, 0xbf, 0xb8, 0x43 // It vs; bic vs r0 r0 r7
};
const byte kInstruction_bic_pl_r2_r2_r1[] = {
  0x58, 0xbf, 0x8a, 0x43 // It pl; bic pl r2 r2 r1
};
const byte kInstruction_bic_vs_r0_r0_r5[] = {
  0x68, 0xbf, 0xa8, 0x43 // It vs; bic vs r0 r0 r5
};
const byte kInstruction_bic_vc_r4_r4_r2[] = {
  0x78, 0xbf, 0x94, 0x43 // It vc; bic vc r4 r4 r2
};
const byte kInstruction_bic_vc_r4_r4_r7[] = {
  0x78, 0xbf, 0xbc, 0x43 // It vc; bic vc r4 r4 r7
};
const byte kInstruction_bic_cs_r4_r4_r7[] = {
  0x28, 0xbf, 0xbc, 0x43 // It cs; bic cs r4 r4 r7
};
const byte kInstruction_bic_ne_r5_r5_r2[] = {
  0x18, 0xbf, 0x95, 0x43 // It ne; bic ne r5 r5 r2
};
const byte kInstruction_bic_eq_r1_r1_r5[] = {
  0x08, 0xbf, 0xa9, 0x43 // It eq; bic eq r1 r1 r5
};
const byte kInstruction_bic_cc_r0_r0_r7[] = {
  0x38, 0xbf, 0xb8, 0x43 // It cc; bic cc r0 r0 r7
};
const byte kInstruction_bic_lt_r4_r4_r0[] = {
  0xb8, 0xbf, 0x84, 0x43 // It lt; bic lt r4 r4 r0
};
const byte kInstruction_bic_eq_r2_r2_r6[] = {
  0x08, 0xbf, 0xb2, 0x43 // It eq; bic eq r2 r2 r6
};
const byte kInstruction_bic_le_r2_r2_r1[] = {
  0xd8, 0xbf, 0x8a, 0x43 // It le; bic le r2 r2 r1
};
const byte kInstruction_bic_mi_r4_r4_r4[] = {
  0x48, 0xbf, 0xa4, 0x43 // It mi; bic mi r4 r4 r4
};
const byte kInstruction_bic_ne_r5_r5_r6[] = {
  0x18, 0xbf, 0xb5, 0x43 // It ne; bic ne r5 r5 r6
};
const byte kInstruction_bic_gt_r0_r0_r7[] = {
  0xc8, 0xbf, 0xb8, 0x43 // It gt; bic gt r0 r0 r7
};
const byte kInstruction_bic_hi_r2_r2_r7[] = {
  0x88, 0xbf, 0xba, 0x43 // It hi; bic hi r2 r2 r7
};
const byte kInstruction_bic_vs_r5_r5_r6[] = {
  0x68, 0xbf, 0xb5, 0x43 // It vs; bic vs r5 r5 r6
};
const byte kInstruction_bic_eq_r4_r4_r1[] = {
  0x08, 0xbf, 0x8c, 0x43 // It eq; bic eq r4 r4 r1
};
const byte kInstruction_bic_eq_r7_r7_r0[] = {
  0x08, 0xbf, 0x87, 0x43 // It eq; bic eq r7 r7 r0
};
const byte kInstruction_bic_ne_r2_r2_r6[] = {
  0x18, 0xbf, 0xb2, 0x43 // It ne; bic ne r2 r2 r6
};
const byte kInstruction_bic_vc_r4_r4_r1[] = {
  0x78, 0xbf, 0x8c, 0x43 // It vc; bic vc r4 r4 r1
};
const byte kInstruction_bic_le_r2_r2_r0[] = {
  0xd8, 0xbf, 0x82, 0x43 // It le; bic le r2 r2 r0
};
const byte kInstruction_bic_lt_r5_r5_r5[] = {
  0xb8, 0xbf, 0xad, 0x43 // It lt; bic lt r5 r5 r5
};
const byte kInstruction_bic_pl_r3_r3_r7[] = {
  0x58, 0xbf, 0xbb, 0x43 // It pl; bic pl r3 r3 r7
};
const byte kInstruction_bic_pl_r1_r1_r5[] = {
  0x58, 0xbf, 0xa9, 0x43 // It pl; bic pl r1 r1 r5
};
const byte kInstruction_bic_le_r3_r3_r1[] = {
  0xd8, 0xbf, 0x8b, 0x43 // It le; bic le r3 r3 r1
};
const byte kInstruction_bic_vs_r3_r3_r2[] = {
  0x68, 0xbf, 0x93, 0x43 // It vs; bic vs r3 r3 r2
};
const byte kInstruction_bic_pl_r1_r1_r3[] = {
  0x58, 0xbf, 0x99, 0x43 // It pl; bic pl r1 r1 r3
};
const byte kInstruction_bic_le_r4_r4_r3[] = {
  0xd8, 0xbf, 0x9c, 0x43 // It le; bic le r4 r4 r3
};
const byte kInstruction_bic_vs_r6_r6_r1[] = {
  0x68, 0xbf, 0x8e, 0x43 // It vs; bic vs r6 r6 r1
};
const byte kInstruction_bic_cs_r1_r1_r1[] = {
  0x28, 0xbf, 0x89, 0x43 // It cs; bic cs r1 r1 r1
};
const byte kInstruction_bic_ge_r2_r2_r6[] = {
  0xa8, 0xbf, 0xb2, 0x43 // It ge; bic ge r2 r2 r6
};
const byte kInstruction_bic_ls_r0_r0_r0[] = {
  0x98, 0xbf, 0x80, 0x43 // It ls; bic ls r0 r0 r0
};
const byte kInstruction_bic_mi_r5_r5_r1[] = {
  0x48, 0xbf, 0x8d, 0x43 // It mi; bic mi r5 r5 r1
};
const byte kInstruction_bic_hi_r4_r4_r1[] = {
  0x88, 0xbf, 0x8c, 0x43 // It hi; bic hi r4 r4 r1
};
const byte kInstruction_bic_eq_r3_r3_r2[] = {
  0x08, 0xbf, 0x93, 0x43 // It eq; bic eq r3 r3 r2
};
const byte kInstruction_bic_cc_r5_r5_r1[] = {
  0x38, 0xbf, 0x8d, 0x43 // It cc; bic cc r5 r5 r1
};
const byte kInstruction_bic_eq_r6_r6_r2[] = {
  0x08, 0xbf, 0x96, 0x43 // It eq; bic eq r6 r6 r2
};
const byte kInstruction_bic_hi_r4_r4_r2[] = {
  0x88, 0xbf, 0x94, 0x43 // It hi; bic hi r4 r4 r2
};
const byte kInstruction_bic_gt_r5_r5_r0[] = {
  0xc8, 0xbf, 0x85, 0x43 // It gt; bic gt r5 r5 r0
};
const byte kInstruction_bic_hi_r3_r3_r2[] = {
  0x88, 0xbf, 0x93, 0x43 // It hi; bic hi r3 r3 r2
};
const byte kInstruction_bic_pl_r0_r0_r0[] = {
  0x58, 0xbf, 0x80, 0x43 // It pl; bic pl r0 r0 r0
};
const byte kInstruction_bic_lt_r3_r3_r7[] = {
  0xb8, 0xbf, 0xbb, 0x43 // It lt; bic lt r3 r3 r7
};
const byte kInstruction_bic_ls_r7_r7_r1[] = {
  0x98, 0xbf, 0x8f, 0x43 // It ls; bic ls r7 r7 r1
};
const byte kInstruction_bic_gt_r3_r3_r3[] = {
  0xc8, 0xbf, 0x9b, 0x43 // It gt; bic gt r3 r3 r3
};
const byte kInstruction_bic_cs_r6_r6_r6[] = {
  0x28, 0xbf, 0xb6, 0x43 // It cs; bic cs r6 r6 r6
};
const byte kInstruction_bic_cc_r3_r3_r2[] = {
  0x38, 0xbf, 0x93, 0x43 // It cc; bic cc r3 r3 r2
};
const byte kInstruction_bic_ne_r4_r4_r0[] = {
  0x18, 0xbf, 0x84, 0x43 // It ne; bic ne r4 r4 r0
};
const byte kInstruction_bic_vs_r4_r4_r5[] = {
  0x68, 0xbf, 0xac, 0x43 // It vs; bic vs r4 r4 r5
};
const byte kInstruction_bic_ge_r6_r6_r4[] = {
  0xa8, 0xbf, 0xa6, 0x43 // It ge; bic ge r6 r6 r4
};
const byte kInstruction_bic_ne_r5_r5_r3[] = {
  0x18, 0xbf, 0x9d, 0x43 // It ne; bic ne r5 r5 r3
};
const byte kInstruction_bic_vs_r3_r3_r0[] = {
  0x68, 0xbf, 0x83, 0x43 // It vs; bic vs r3 r3 r0
};
const byte kInstruction_bic_lt_r5_r5_r2[] = {
  0xb8, 0xbf, 0x95, 0x43 // It lt; bic lt r5 r5 r2
};
const byte kInstruction_bic_lt_r6_r6_r4[] = {
  0xb8, 0xbf, 0xa6, 0x43 // It lt; bic lt r6 r6 r4
};
const byte kInstruction_bic_hi_r2_r2_r5[] = {
  0x88, 0xbf, 0xaa, 0x43 // It hi; bic hi r2 r2 r5
};
const byte kInstruction_bic_eq_r7_r7_r5[] = {
  0x08, 0xbf, 0xaf, 0x43 // It eq; bic eq r7 r7 r5
};
const byte kInstruction_bic_lt_r4_r4_r5[] = {
  0xb8, 0xbf, 0xac, 0x43 // It lt; bic lt r4 r4 r5
};
const byte kInstruction_bic_ls_r7_r7_r3[] = {
  0x98, 0xbf, 0x9f, 0x43 // It ls; bic ls r7 r7 r3
};
const byte kInstruction_bic_lt_r3_r3_r5[] = {
  0xb8, 0xbf, 0xab, 0x43 // It lt; bic lt r3 r3 r5
};
const byte kInstruction_bic_cs_r5_r5_r0[] = {
  0x28, 0xbf, 0x85, 0x43 // It cs; bic cs r5 r5 r0
};
const byte kInstruction_bic_vc_r2_r2_r3[] = {
  0x78, 0xbf, 0x9a, 0x43 // It vc; bic vc r2 r2 r3
};
const byte kInstruction_bic_cs_r1_r1_r4[] = {
  0x28, 0xbf, 0xa1, 0x43 // It cs; bic cs r1 r1 r4
};
const byte kInstruction_bic_pl_r5_r5_r4[] = {
  0x58, 0xbf, 0xa5, 0x43 // It pl; bic pl r5 r5 r4
};
const byte kInstruction_bic_hi_r7_r7_r4[] = {
  0x88, 0xbf, 0xa7, 0x43 // It hi; bic hi r7 r7 r4
};
const byte kInstruction_bic_ge_r3_r3_r6[] = {
  0xa8, 0xbf, 0xb3, 0x43 // It ge; bic ge r3 r3 r6
};
const byte kInstruction_bic_ls_r3_r3_r2[] = {
  0x98, 0xbf, 0x93, 0x43 // It ls; bic ls r3 r3 r2
};
const byte kInstruction_bic_mi_r3_r3_r3[] = {
  0x48, 0xbf, 0x9b, 0x43 // It mi; bic mi r3 r3 r3
};
const byte kInstruction_bic_le_r6_r6_r5[] = {
  0xd8, 0xbf, 0xae, 0x43 // It le; bic le r6 r6 r5
};
const byte kInstruction_bic_pl_r5_r5_r7[] = {
  0x58, 0xbf, 0xbd, 0x43 // It pl; bic pl r5 r5 r7
};
const byte kInstruction_bic_ne_r2_r2_r3[] = {
  0x18, 0xbf, 0x9a, 0x43 // It ne; bic ne r2 r2 r3
};
const byte kInstruction_bic_ls_r2_r2_r6[] = {
  0x98, 0xbf, 0xb2, 0x43 // It ls; bic ls r2 r2 r6
};
const byte kInstruction_bic_le_r1_r1_r6[] = {
  0xd8, 0xbf, 0xb1, 0x43 // It le; bic le r1 r1 r6
};
const byte kInstruction_bic_cc_r6_r6_r7[] = {
  0x38, 0xbf, 0xbe, 0x43 // It cc; bic cc r6 r6 r7
};
const byte kInstruction_bic_pl_r4_r4_r3[] = {
  0x58, 0xbf, 0x9c, 0x43 // It pl; bic pl r4 r4 r3
};
const byte kInstruction_bic_ne_r0_r0_r3[] = {
  0x18, 0xbf, 0x98, 0x43 // It ne; bic ne r0 r0 r3
};
const byte kInstruction_bic_cc_r6_r6_r6[] = {
  0x38, 0xbf, 0xb6, 0x43 // It cc; bic cc r6 r6 r6
};
const byte kInstruction_bic_ls_r7_r7_r5[] = {
  0x98, 0xbf, 0xaf, 0x43 // It ls; bic ls r7 r7 r5
};
const byte kInstruction_bic_ls_r1_r1_r5[] = {
  0x98, 0xbf, 0xa9, 0x43 // It ls; bic ls r1 r1 r5
};
const byte kInstruction_bic_le_r0_r0_r0[] = {
  0xd8, 0xbf, 0x80, 0x43 // It le; bic le r0 r0 r0
};
const byte kInstruction_bic_ge_r4_r4_r6[] = {
  0xa8, 0xbf, 0xb4, 0x43 // It ge; bic ge r4 r4 r6
};
const byte kInstruction_bic_cc_r1_r1_r6[] = {
  0x38, 0xbf, 0xb1, 0x43 // It cc; bic cc r1 r1 r6
};
const byte kInstruction_bic_eq_r4_r4_r3[] = {
  0x08, 0xbf, 0x9c, 0x43 // It eq; bic eq r4 r4 r3
};
const byte kInstruction_bic_ls_r7_r7_r4[] = {
  0x98, 0xbf, 0xa7, 0x43 // It ls; bic ls r7 r7 r4
};
const byte kInstruction_bic_eq_r3_r3_r0[] = {
  0x08, 0xbf, 0x83, 0x43 // It eq; bic eq r3 r3 r0
};
const byte kInstruction_bic_lt_r4_r4_r3[] = {
  0xb8, 0xbf, 0x9c, 0x43 // It lt; bic lt r4 r4 r3
};
const byte kInstruction_bic_le_r3_r3_r4[] = {
  0xd8, 0xbf, 0xa3, 0x43 // It le; bic le r3 r3 r4
};
const byte kInstruction_bic_le_r4_r4_r4[] = {
  0xd8, 0xbf, 0xa4, 0x43 // It le; bic le r4 r4 r4
};
const byte kInstruction_bic_ge_r0_r0_r6[] = {
  0xa8, 0xbf, 0xb0, 0x43 // It ge; bic ge r0 r0 r6
};
const byte kInstruction_bic_hi_r7_r7_r2[] = {
  0x88, 0xbf, 0x97, 0x43 // It hi; bic hi r7 r7 r2
};
const byte kInstruction_bic_pl_r5_r5_r6[] = {
  0x58, 0xbf, 0xb5, 0x43 // It pl; bic pl r5 r5 r6
};
const byte kInstruction_bic_pl_r4_r4_r7[] = {
  0x58, 0xbf, 0xbc, 0x43 // It pl; bic pl r4 r4 r7
};
const byte kInstruction_bic_gt_r3_r3_r6[] = {
  0xc8, 0xbf, 0xb3, 0x43 // It gt; bic gt r3 r3 r6
};
const byte kInstruction_bic_eq_r6_r6_r6[] = {
  0x08, 0xbf, 0xb6, 0x43 // It eq; bic eq r6 r6 r6
};
const byte kInstruction_bic_cc_r5_r5_r0[] = {
  0x38, 0xbf, 0x85, 0x43 // It cc; bic cc r5 r5 r0
};
const byte kInstruction_bic_hi_r5_r5_r0[] = {
  0x88, 0xbf, 0x85, 0x43 // It hi; bic hi r5 r5 r0
};
const byte kInstruction_bic_gt_r5_r5_r5[] = {
  0xc8, 0xbf, 0xad, 0x43 // It gt; bic gt r5 r5 r5
};
const byte kInstruction_bic_vs_r2_r2_r4[] = {
  0x68, 0xbf, 0xa2, 0x43 // It vs; bic vs r2 r2 r4
};
const byte kInstruction_bic_vs_r1_r1_r3[] = {
  0x68, 0xbf, 0x99, 0x43 // It vs; bic vs r1 r1 r3
};
const byte kInstruction_bic_lt_r7_r7_r6[] = {
  0xb8, 0xbf, 0xb7, 0x43 // It lt; bic lt r7 r7 r6
};
const byte kInstruction_bic_ge_r2_r2_r2[] = {
  0xa8, 0xbf, 0x92, 0x43 // It ge; bic ge r2 r2 r2
};
const byte kInstruction_bic_mi_r1_r1_r5[] = {
  0x48, 0xbf, 0xa9, 0x43 // It mi; bic mi r1 r1 r5
};
const byte kInstruction_bic_ge_r5_r5_r0[] = {
  0xa8, 0xbf, 0x85, 0x43 // It ge; bic ge r5 r5 r0
};
const byte kInstruction_bic_le_r6_r6_r3[] = {
  0xd8, 0xbf, 0x9e, 0x43 // It le; bic le r6 r6 r3
};
const byte kInstruction_bic_hi_r7_r7_r5[] = {
  0x88, 0xbf, 0xaf, 0x43 // It hi; bic hi r7 r7 r5
};
const byte kInstruction_bic_gt_r3_r3_r4[] = {
  0xc8, 0xbf, 0xa3, 0x43 // It gt; bic gt r3 r3 r4
};
const byte kInstruction_bic_cc_r3_r3_r3[] = {
  0x38, 0xbf, 0x9b, 0x43 // It cc; bic cc r3 r3 r3
};
const byte kInstruction_bic_hi_r2_r2_r2[] = {
  0x88, 0xbf, 0x92, 0x43 // It hi; bic hi r2 r2 r2
};
const byte kInstruction_bic_lt_r7_r7_r3[] = {
  0xb8, 0xbf, 0x9f, 0x43 // It lt; bic lt r7 r7 r3
};
const byte kInstruction_bic_ls_r6_r6_r6[] = {
  0x98, 0xbf, 0xb6, 0x43 // It ls; bic ls r6 r6 r6
};
const byte kInstruction_bic_le_r7_r7_r7[] = {
  0xd8, 0xbf, 0xbf, 0x43 // It le; bic le r7 r7 r7
};
const byte kInstruction_bic_cs_r4_r4_r6[] = {
  0x28, 0xbf, 0xb4, 0x43 // It cs; bic cs r4 r4 r6
};
const byte kInstruction_bic_ge_r5_r5_r4[] = {
  0xa8, 0xbf, 0xa5, 0x43 // It ge; bic ge r5 r5 r4
};
const byte kInstruction_bic_ge_r1_r1_r2[] = {
  0xa8, 0xbf, 0x91, 0x43 // It ge; bic ge r1 r1 r2
};
const byte kInstruction_bic_pl_r0_r0_r7[] = {
  0x58, 0xbf, 0xb8, 0x43 // It pl; bic pl r0 r0 r7
};
const byte kInstruction_bic_vs_r1_r1_r2[] = {
  0x68, 0xbf, 0x91, 0x43 // It vs; bic vs r1 r1 r2
};
const byte kInstruction_bic_mi_r6_r6_r5[] = {
  0x48, 0xbf, 0xae, 0x43 // It mi; bic mi r6 r6 r5
};
const byte kInstruction_bic_mi_r0_r0_r1[] = {
  0x48, 0xbf, 0x88, 0x43 // It mi; bic mi r0 r0 r1
};
const byte kInstruction_bic_vc_r0_r0_r5[] = {
  0x78, 0xbf, 0xa8, 0x43 // It vc; bic vc r0 r0 r5
};
const byte kInstruction_bic_cc_r5_r5_r5[] = {
  0x38, 0xbf, 0xad, 0x43 // It cc; bic cc r5 r5 r5
};
const byte kInstruction_bic_pl_r5_r5_r5[] = {
  0x58, 0xbf, 0xad, 0x43 // It pl; bic pl r5 r5 r5
};
const byte kInstruction_bic_ne_r2_r2_r0[] = {
  0x18, 0xbf, 0x82, 0x43 // It ne; bic ne r2 r2 r0
};
const byte kInstruction_bic_cc_r3_r3_r4[] = {
  0x38, 0xbf, 0xa3, 0x43 // It cc; bic cc r3 r3 r4
};
const byte kInstruction_bic_ls_r3_r3_r3[] = {
  0x98, 0xbf, 0x9b, 0x43 // It ls; bic ls r3 r3 r3
};
const byte kInstruction_bic_cc_r2_r2_r1[] = {
  0x38, 0xbf, 0x8a, 0x43 // It cc; bic cc r2 r2 r1
};
const byte kInstruction_bic_ge_r3_r3_r4[] = {
  0xa8, 0xbf, 0xa3, 0x43 // It ge; bic ge r3 r3 r4
};
const byte kInstruction_bic_ne_r0_r0_r6[] = {
  0x18, 0xbf, 0xb0, 0x43 // It ne; bic ne r0 r0 r6
};
const byte kInstruction_bic_vs_r2_r2_r0[] = {
  0x68, 0xbf, 0x82, 0x43 // It vs; bic vs r2 r2 r0
};
const byte kInstruction_bic_ne_r1_r1_r2[] = {
  0x18, 0xbf, 0x91, 0x43 // It ne; bic ne r1 r1 r2
};
const byte kInstruction_bic_ne_r6_r6_r5[] = {
  0x18, 0xbf, 0xae, 0x43 // It ne; bic ne r6 r6 r5
};
const byte kInstruction_bic_pl_r7_r7_r0[] = {
  0x58, 0xbf, 0x87, 0x43 // It pl; bic pl r7 r7 r0
};
const byte kInstruction_bic_pl_r6_r6_r2[] = {
  0x58, 0xbf, 0x96, 0x43 // It pl; bic pl r6 r6 r2
};
const byte kInstruction_bic_pl_r1_r1_r2[] = {
  0x58, 0xbf, 0x91, 0x43 // It pl; bic pl r1 r1 r2
};
const byte kInstruction_bic_gt_r6_r6_r3[] = {
  0xc8, 0xbf, 0x9e, 0x43 // It gt; bic gt r6 r6 r3
};
const byte kInstruction_bic_vc_r0_r0_r4[] = {
  0x78, 0xbf, 0xa0, 0x43 // It vc; bic vc r0 r0 r4
};
const byte kInstruction_bic_vc_r4_r4_r5[] = {
  0x78, 0xbf, 0xac, 0x43 // It vc; bic vc r4 r4 r5
};
const byte kInstruction_bic_vs_r2_r2_r3[] = {
  0x68, 0xbf, 0x9a, 0x43 // It vs; bic vs r2 r2 r3
};
const byte kInstruction_bic_pl_r2_r2_r3[] = {
  0x58, 0xbf, 0x9a, 0x43 // It pl; bic pl r2 r2 r3
};
const byte kInstruction_bic_hi_r5_r5_r2[] = {
  0x88, 0xbf, 0x95, 0x43 // It hi; bic hi r5 r5 r2
};
const byte kInstruction_bic_le_r6_r6_r1[] = {
  0xd8, 0xbf, 0x8e, 0x43 // It le; bic le r6 r6 r1
};
const byte kInstruction_bic_ne_r3_r3_r0[] = {
  0x18, 0xbf, 0x83, 0x43 // It ne; bic ne r3 r3 r0
};
const byte kInstruction_bic_mi_r7_r7_r1[] = {
  0x48, 0xbf, 0x8f, 0x43 // It mi; bic mi r7 r7 r1
};
const byte kInstruction_bic_lt_r7_r7_r7[] = {
  0xb8, 0xbf, 0xbf, 0x43 // It lt; bic lt r7 r7 r7
};
const byte kInstruction_bic_gt_r5_r5_r7[] = {
  0xc8, 0xbf, 0xbd, 0x43 // It gt; bic gt r5 r5 r7
};
const byte kInstruction_bic_vc_r1_r1_r1[] = {
  0x78, 0xbf, 0x89, 0x43 // It vc; bic vc r1 r1 r1
};
const byte kInstruction_bic_lt_r1_r1_r2[] = {
  0xb8, 0xbf, 0x91, 0x43 // It lt; bic lt r1 r1 r2
};
const byte kInstruction_bic_vs_r6_r6_r6[] = {
  0x68, 0xbf, 0xb6, 0x43 // It vs; bic vs r6 r6 r6
};
const byte kInstruction_bic_le_r5_r5_r5[] = {
  0xd8, 0xbf, 0xad, 0x43 // It le; bic le r5 r5 r5
};
const byte kInstruction_bic_gt_r6_r6_r7[] = {
  0xc8, 0xbf, 0xbe, 0x43 // It gt; bic gt r6 r6 r7
};
const byte kInstruction_bic_cc_r3_r3_r1[] = {
  0x38, 0xbf, 0x8b, 0x43 // It cc; bic cc r3 r3 r1
};
const byte kInstruction_bic_ls_r1_r1_r0[] = {
  0x98, 0xbf, 0x81, 0x43 // It ls; bic ls r1 r1 r0
};
const byte kInstruction_bic_vs_r6_r6_r2[] = {
  0x68, 0xbf, 0x96, 0x43 // It vs; bic vs r6 r6 r2
};
const byte kInstruction_bic_mi_r7_r7_r0[] = {
  0x48, 0xbf, 0x87, 0x43 // It mi; bic mi r7 r7 r0
};
const byte kInstruction_bic_gt_r0_r0_r1[] = {
  0xc8, 0xbf, 0x88, 0x43 // It gt; bic gt r0 r0 r1
};
const byte kInstruction_bic_ne_r0_r0_r0[] = {
  0x18, 0xbf, 0x80, 0x43 // It ne; bic ne r0 r0 r0
};
const byte kInstruction_bic_lt_r6_r6_r1[] = {
  0xb8, 0xbf, 0x8e, 0x43 // It lt; bic lt r6 r6 r1
};
const byte kInstruction_bic_ge_r5_r5_r5[] = {
  0xa8, 0xbf, 0xad, 0x43 // It ge; bic ge r5 r5 r5
};
const byte kInstruction_bic_lt_r2_r2_r4[] = {
  0xb8, 0xbf, 0xa2, 0x43 // It lt; bic lt r2 r2 r4
};
const byte kInstruction_bic_vs_r4_r4_r3[] = {
  0x68, 0xbf, 0x9c, 0x43 // It vs; bic vs r4 r4 r3
};
const byte kInstruction_bic_cs_r5_r5_r2[] = {
  0x28, 0xbf, 0x95, 0x43 // It cs; bic cs r5 r5 r2
};
const byte kInstruction_bic_gt_r1_r1_r1[] = {
  0xc8, 0xbf, 0x89, 0x43 // It gt; bic gt r1 r1 r1
};
const byte kInstruction_bic_cs_r5_r5_r6[] = {
  0x28, 0xbf, 0xb5, 0x43 // It cs; bic cs r5 r5 r6
};
const byte kInstruction_bic_gt_r6_r6_r2[] = {
  0xc8, 0xbf, 0x96, 0x43 // It gt; bic gt r6 r6 r2
};
const byte kInstruction_bic_cc_r2_r2_r0[] = {
  0x38, 0xbf, 0x82, 0x43 // It cc; bic cc r2 r2 r0
};
const byte kInstruction_bic_lt_r2_r2_r5[] = {
  0xb8, 0xbf, 0xaa, 0x43 // It lt; bic lt r2 r2 r5
};
const byte kInstruction_bic_mi_r1_r1_r6[] = {
  0x48, 0xbf, 0xb1, 0x43 // It mi; bic mi r1 r1 r6
};
const byte kInstruction_bic_hi_r4_r4_r0[] = {
  0x88, 0xbf, 0x84, 0x43 // It hi; bic hi r4 r4 r0
};
const byte kInstruction_bic_le_r5_r5_r2[] = {
  0xd8, 0xbf, 0x95, 0x43 // It le; bic le r5 r5 r2
};
const byte kInstruction_bic_eq_r5_r5_r7[] = {
  0x08, 0xbf, 0xbd, 0x43 // It eq; bic eq r5 r5 r7
};
const byte kInstruction_bic_eq_r5_r5_r0[] = {
  0x08, 0xbf, 0x85, 0x43 // It eq; bic eq r5 r5 r0
};
const byte kInstruction_bic_le_r0_r0_r1[] = {
  0xd8, 0xbf, 0x88, 0x43 // It le; bic le r0 r0 r1
};
const byte kInstruction_bic_cs_r2_r2_r4[] = {
  0x28, 0xbf, 0xa2, 0x43 // It cs; bic cs r2 r2 r4
};
const byte kInstruction_bic_cc_r5_r5_r4[] = {
  0x38, 0xbf, 0xa5, 0x43 // It cc; bic cc r5 r5 r4
};
const byte kInstruction_bic_mi_r5_r5_r0[] = {
  0x48, 0xbf, 0x85, 0x43 // It mi; bic mi r5 r5 r0
};
const byte kInstruction_bic_le_r1_r1_r0[] = {
  0xd8, 0xbf, 0x81, 0x43 // It le; bic le r1 r1 r0
};
const byte kInstruction_bic_mi_r2_r2_r2[] = {
  0x48, 0xbf, 0x92, 0x43 // It mi; bic mi r2 r2 r2
};
const byte kInstruction_bic_ls_r4_r4_r2[] = {
  0x98, 0xbf, 0x94, 0x43 // It ls; bic ls r4 r4 r2
};
const byte kInstruction_bic_ne_r3_r3_r1[] = {
  0x18, 0xbf, 0x8b, 0x43 // It ne; bic ne r3 r3 r1
};
const byte kInstruction_bic_hi_r3_r3_r1[] = {
  0x88, 0xbf, 0x8b, 0x43 // It hi; bic hi r3 r3 r1
};
const byte kInstruction_bic_pl_r4_r4_r1[] = {
  0x58, 0xbf, 0x8c, 0x43 // It pl; bic pl r4 r4 r1
};
const byte kInstruction_bic_pl_r7_r7_r7[] = {
  0x58, 0xbf, 0xbf, 0x43 // It pl; bic pl r7 r7 r7
};
const byte kInstruction_bic_ge_r3_r3_r0[] = {
  0xa8, 0xbf, 0x83, 0x43 // It ge; bic ge r3 r3 r0
};
const byte kInstruction_bic_vs_r6_r6_r0[] = {
  0x68, 0xbf, 0x86, 0x43 // It vs; bic vs r6 r6 r0
};
const byte kInstruction_bic_gt_r1_r1_r5[] = {
  0xc8, 0xbf, 0xa9, 0x43 // It gt; bic gt r1 r1 r5
};
const byte kInstruction_bic_ls_r1_r1_r7[] = {
  0x98, 0xbf, 0xb9, 0x43 // It ls; bic ls r1 r1 r7
};
const byte kInstruction_bic_hi_r5_r5_r3[] = {
  0x88, 0xbf, 0x9d, 0x43 // It hi; bic hi r5 r5 r3
};
const byte kInstruction_bic_ls_r5_r5_r2[] = {
  0x98, 0xbf, 0x95, 0x43 // It ls; bic ls r5 r5 r2
};
const byte kInstruction_bic_ls_r6_r6_r2[] = {
  0x98, 0xbf, 0x96, 0x43 // It ls; bic ls r6 r6 r2
};
const byte kInstruction_bic_cs_r7_r7_r7[] = {
  0x28, 0xbf, 0xbf, 0x43 // It cs; bic cs r7 r7 r7
};
const byte kInstruction_bic_le_r3_r3_r2[] = {
  0xd8, 0xbf, 0x93, 0x43 // It le; bic le r3 r3 r2
};
const byte kInstruction_bic_le_r6_r6_r0[] = {
  0xd8, 0xbf, 0x86, 0x43 // It le; bic le r6 r6 r0
};
const byte kInstruction_bic_pl_r4_r4_r4[] = {
  0x58, 0xbf, 0xa4, 0x43 // It pl; bic pl r4 r4 r4
};
const byte kInstruction_bic_ne_r1_r1_r3[] = {
  0x18, 0xbf, 0x99, 0x43 // It ne; bic ne r1 r1 r3
};
const byte kInstruction_bic_ge_r5_r5_r1[] = {
  0xa8, 0xbf, 0x8d, 0x43 // It ge; bic ge r5 r5 r1
};
const byte kInstruction_bic_eq_r4_r4_r7[] = {
  0x08, 0xbf, 0xbc, 0x43 // It eq; bic eq r4 r4 r7
};
const byte kInstruction_bic_pl_r7_r7_r1[] = {
  0x58, 0xbf, 0x8f, 0x43 // It pl; bic pl r7 r7 r1
};
const byte kInstruction_bic_vs_r6_r6_r7[] = {
  0x68, 0xbf, 0xbe, 0x43 // It vs; bic vs r6 r6 r7
};
const byte kInstruction_bic_vc_r2_r2_r6[] = {
  0x78, 0xbf, 0xb2, 0x43 // It vc; bic vc r2 r2 r6
};
const byte kInstruction_bic_hi_r7_r7_r6[] = {
  0x88, 0xbf, 0xb7, 0x43 // It hi; bic hi r7 r7 r6
};
const byte kInstruction_bic_le_r1_r1_r1[] = {
  0xd8, 0xbf, 0x89, 0x43 // It le; bic le r1 r1 r1
};
const byte kInstruction_bic_cs_r4_r4_r1[] = {
  0x28, 0xbf, 0x8c, 0x43 // It cs; bic cs r4 r4 r1
};
const byte kInstruction_bic_mi_r1_r1_r2[] = {
  0x48, 0xbf, 0x91, 0x43 // It mi; bic mi r1 r1 r2
};
const byte kInstruction_bic_pl_r3_r3_r5[] = {
  0x58, 0xbf, 0xab, 0x43 // It pl; bic pl r3 r3 r5
};
const byte kInstruction_bic_eq_r7_r7_r1[] = {
  0x08, 0xbf, 0x8f, 0x43 // It eq; bic eq r7 r7 r1
};
const byte kInstruction_bic_cs_r0_r0_r5[] = {
  0x28, 0xbf, 0xa8, 0x43 // It cs; bic cs r0 r0 r5
};
const byte kInstruction_bic_ge_r3_r3_r5[] = {
  0xa8, 0xbf, 0xab, 0x43 // It ge; bic ge r3 r3 r5
};
const byte kInstruction_bic_pl_r6_r6_r3[] = {
  0x58, 0xbf, 0x9e, 0x43 // It pl; bic pl r6 r6 r3
};
const byte kInstruction_bic_cc_r7_r7_r5[] = {
  0x38, 0xbf, 0xaf, 0x43 // It cc; bic cc r7 r7 r5
};
const byte kInstruction_bic_lt_r4_r4_r6[] = {
  0xb8, 0xbf, 0xb4, 0x43 // It lt; bic lt r4 r4 r6
};
const byte kInstruction_bic_ne_r7_r7_r2[] = {
  0x18, 0xbf, 0x97, 0x43 // It ne; bic ne r7 r7 r2
};
const byte kInstruction_bic_vc_r3_r3_r0[] = {
  0x78, 0xbf, 0x83, 0x43 // It vc; bic vc r3 r3 r0
};
const byte kInstruction_bic_cc_r7_r7_r6[] = {
  0x38, 0xbf, 0xb7, 0x43 // It cc; bic cc r7 r7 r6
};
const byte kInstruction_bic_vc_r0_r0_r0[] = {
  0x78, 0xbf, 0x80, 0x43 // It vc; bic vc r0 r0 r0
};
const byte kInstruction_bic_vc_r7_r7_r3[] = {
  0x78, 0xbf, 0x9f, 0x43 // It vc; bic vc r7 r7 r3
};
const byte kInstruction_bic_vs_r7_r7_r0[] = {
  0x68, 0xbf, 0x87, 0x43 // It vs; bic vs r7 r7 r0
};
const byte kInstruction_bic_eq_r2_r2_r0[] = {
  0x08, 0xbf, 0x82, 0x43 // It eq; bic eq r2 r2 r0
};
const byte kInstruction_bic_ne_r2_r2_r1[] = {
  0x18, 0xbf, 0x8a, 0x43 // It ne; bic ne r2 r2 r1
};
const byte kInstruction_bic_pl_r7_r7_r2[] = {
  0x58, 0xbf, 0x97, 0x43 // It pl; bic pl r7 r7 r2
};
const byte kInstruction_bic_vc_r3_r3_r6[] = {
  0x78, 0xbf, 0xb3, 0x43 // It vc; bic vc r3 r3 r6
};
const byte kInstruction_bic_vs_r5_r5_r1[] = {
  0x68, 0xbf, 0x8d, 0x43 // It vs; bic vs r5 r5 r1
};
const byte kInstruction_bic_vs_r2_r2_r2[] = {
  0x68, 0xbf, 0x92, 0x43 // It vs; bic vs r2 r2 r2
};
const byte kInstruction_bic_pl_r6_r6_r6[] = {
  0x58, 0xbf, 0xb6, 0x43 // It pl; bic pl r6 r6 r6
};
const byte kInstruction_bic_ge_r6_r6_r3[] = {
  0xa8, 0xbf, 0x9e, 0x43 // It ge; bic ge r6 r6 r3
};
const byte kInstruction_bic_lt_r2_r2_r6[] = {
  0xb8, 0xbf, 0xb2, 0x43 // It lt; bic lt r2 r2 r6
};
const byte kInstruction_bic_ls_r5_r5_r6[] = {
  0x98, 0xbf, 0xb5, 0x43 // It ls; bic ls r5 r5 r6
};
const byte kInstruction_bic_le_r7_r7_r6[] = {
  0xd8, 0xbf, 0xb7, 0x43 // It le; bic le r7 r7 r6
};
const byte kInstruction_bic_ge_r0_r0_r2[] = {
  0xa8, 0xbf, 0x90, 0x43 // It ge; bic ge r0 r0 r2
};
const byte kInstruction_bic_le_r0_r0_r4[] = {
  0xd8, 0xbf, 0xa0, 0x43 // It le; bic le r0 r0 r4
};
const byte kInstruction_bic_ls_r6_r6_r3[] = {
  0x98, 0xbf, 0x9e, 0x43 // It ls; bic ls r6 r6 r3
};
const byte kInstruction_bic_ls_r6_r6_r0[] = {
  0x98, 0xbf, 0x86, 0x43 // It ls; bic ls r6 r6 r0
};
const byte kInstruction_bic_vs_r4_r4_r7[] = {
  0x68, 0xbf, 0xbc, 0x43 // It vs; bic vs r4 r4 r7
};
const byte kInstruction_bic_cs_r4_r4_r4[] = {
  0x28, 0xbf, 0xa4, 0x43 // It cs; bic cs r4 r4 r4
};
const byte kInstruction_bic_cs_r7_r7_r5[] = {
  0x28, 0xbf, 0xaf, 0x43 // It cs; bic cs r7 r7 r5
};
const byte kInstruction_bic_cs_r6_r6_r3[] = {
  0x28, 0xbf, 0x9e, 0x43 // It cs; bic cs r6 r6 r3
};
const byte kInstruction_bic_eq_r7_r7_r4[] = {
  0x08, 0xbf, 0xa7, 0x43 // It eq; bic eq r7 r7 r4
};
const byte kInstruction_bic_pl_r6_r6_r0[] = {
  0x58, 0xbf, 0x86, 0x43 // It pl; bic pl r6 r6 r0
};
const byte kInstruction_bic_hi_r5_r5_r4[] = {
  0x88, 0xbf, 0xa5, 0x43 // It hi; bic hi r5 r5 r4
};
const byte kInstruction_bic_lt_r6_r6_r6[] = {
  0xb8, 0xbf, 0xb6, 0x43 // It lt; bic lt r6 r6 r6
};
const byte kInstruction_bic_le_r7_r7_r2[] = {
  0xd8, 0xbf, 0x97, 0x43 // It le; bic le r7 r7 r2
};
const byte kInstruction_bic_le_r4_r4_r1[] = {
  0xd8, 0xbf, 0x8c, 0x43 // It le; bic le r4 r4 r1
};
const byte kInstruction_bic_ne_r4_r4_r6[] = {
  0x18, 0xbf, 0xb4, 0x43 // It ne; bic ne r4 r4 r6
};
const byte kInstruction_bic_hi_r0_r0_r1[] = {
  0x88, 0xbf, 0x88, 0x43 // It hi; bic hi r0 r0 r1
};
const byte kInstruction_bic_gt_r6_r6_r5[] = {
  0xc8, 0xbf, 0xae, 0x43 // It gt; bic gt r6 r6 r5
};
const byte kInstruction_bic_cc_r5_r5_r6[] = {
  0x38, 0xbf, 0xb5, 0x43 // It cc; bic cc r5 r5 r6
};
const byte kInstruction_bic_ls_r3_r3_r4[] = {
  0x98, 0xbf, 0xa3, 0x43 // It ls; bic ls r3 r3 r4
};
const byte kInstruction_bic_vc_r6_r6_r6[] = {
  0x78, 0xbf, 0xb6, 0x43 // It vc; bic vc r6 r6 r6
};
const byte kInstruction_bic_pl_r4_r4_r2[] = {
  0x58, 0xbf, 0x94, 0x43 // It pl; bic pl r4 r4 r2
};
const byte kInstruction_bic_lt_r6_r6_r3[] = {
  0xb8, 0xbf, 0x9e, 0x43 // It lt; bic lt r6 r6 r3
};
const byte kInstruction_bic_mi_r1_r1_r0[] = {
  0x48, 0xbf, 0x81, 0x43 // It mi; bic mi r1 r1 r0
};
const byte kInstruction_bic_cc_r0_r0_r2[] = {
  0x38, 0xbf, 0x90, 0x43 // It cc; bic cc r0 r0 r2
};
const byte kInstruction_bic_ne_r5_r5_r5[] = {
  0x18, 0xbf, 0xad, 0x43 // It ne; bic ne r5 r5 r5
};
const byte kInstruction_bic_cs_r7_r7_r4[] = {
  0x28, 0xbf, 0xa7, 0x43 // It cs; bic cs r7 r7 r4
};
const byte kInstruction_bic_vc_r7_r7_r0[] = {
  0x78, 0xbf, 0x87, 0x43 // It vc; bic vc r7 r7 r0
};
const byte kInstruction_bic_cc_r2_r2_r2[] = {
  0x38, 0xbf, 0x92, 0x43 // It cc; bic cc r2 r2 r2
};
const byte kInstruction_bic_ge_r0_r0_r4[] = {
  0xa8, 0xbf, 0xa0, 0x43 // It ge; bic ge r0 r0 r4
};
const byte kInstruction_bic_gt_r4_r4_r4[] = {
  0xc8, 0xbf, 0xa4, 0x43 // It gt; bic gt r4 r4 r4
};
const byte kInstruction_bic_cs_r3_r3_r6[] = {
  0x28, 0xbf, 0xb3, 0x43 // It cs; bic cs r3 r3 r6
};
const byte kInstruction_bic_cc_r4_r4_r2[] = {
  0x38, 0xbf, 0x94, 0x43 // It cc; bic cc r4 r4 r2
};
const byte kInstruction_bic_eq_r1_r1_r6[] = {
  0x08, 0xbf, 0xb1, 0x43 // It eq; bic eq r1 r1 r6
};
const byte kInstruction_bic_mi_r4_r4_r6[] = {
  0x48, 0xbf, 0xb4, 0x43 // It mi; bic mi r4 r4 r6
};
const byte kInstruction_bic_eq_r4_r4_r4[] = {
  0x08, 0xbf, 0xa4, 0x43 // It eq; bic eq r4 r4 r4
};
const byte kInstruction_bic_gt_r2_r2_r6[] = {
  0xc8, 0xbf, 0xb2, 0x43 // It gt; bic gt r2 r2 r6
};
const byte kInstruction_bic_lt_r5_r5_r7[] = {
  0xb8, 0xbf, 0xbd, 0x43 // It lt; bic lt r5 r5 r7
};
const byte kInstruction_bic_lt_r4_r4_r2[] = {
  0xb8, 0xbf, 0x94, 0x43 // It lt; bic lt r4 r4 r2
};
const byte kInstruction_bic_cs_r6_r6_r1[] = {
  0x28, 0xbf, 0x8e, 0x43 // It cs; bic cs r6 r6 r1
};
const byte kInstruction_bic_vs_r2_r2_r7[] = {
  0x68, 0xbf, 0xba, 0x43 // It vs; bic vs r2 r2 r7
};
const byte kInstruction_bic_hi_r6_r6_r6[] = {
  0x88, 0xbf, 0xb6, 0x43 // It hi; bic hi r6 r6 r6
};
const byte kInstruction_bic_vs_r0_r0_r3[] = {
  0x68, 0xbf, 0x98, 0x43 // It vs; bic vs r0 r0 r3
};
const byte kInstruction_bic_mi_r0_r0_r2[] = {
  0x48, 0xbf, 0x90, 0x43 // It mi; bic mi r0 r0 r2
};
const byte kInstruction_bic_cs_r7_r7_r1[] = {
  0x28, 0xbf, 0x8f, 0x43 // It cs; bic cs r7 r7 r1
};
const byte kInstruction_bic_gt_r1_r1_r6[] = {
  0xc8, 0xbf, 0xb1, 0x43 // It gt; bic gt r1 r1 r6
};
const byte kInstruction_bic_vs_r3_r3_r7[] = {
  0x68, 0xbf, 0xbb, 0x43 // It vs; bic vs r3 r3 r7
};
const byte kInstruction_bic_hi_r1_r1_r5[] = {
  0x88, 0xbf, 0xa9, 0x43 // It hi; bic hi r1 r1 r5
};
const byte kInstruction_bic_lt_r4_r4_r1[] = {
  0xb8, 0xbf, 0x8c, 0x43 // It lt; bic lt r4 r4 r1
};
const byte kInstruction_bic_le_r6_r6_r6[] = {
  0xd8, 0xbf, 0xb6, 0x43 // It le; bic le r6 r6 r6
};
const byte kInstruction_bic_vc_r7_r7_r6[] = {
  0x78, 0xbf, 0xb7, 0x43 // It vc; bic vc r7 r7 r6
};
const byte kInstruction_bic_gt_r4_r4_r5[] = {
  0xc8, 0xbf, 0xac, 0x43 // It gt; bic gt r4 r4 r5
};
const byte kInstruction_bic_le_r1_r1_r4[] = {
  0xd8, 0xbf, 0xa1, 0x43 // It le; bic le r1 r1 r4
};
const byte kInstruction_bic_mi_r2_r2_r1[] = {
  0x48, 0xbf, 0x8a, 0x43 // It mi; bic mi r2 r2 r1
};
const byte kInstruction_bic_ls_r3_r3_r1[] = {
  0x98, 0xbf, 0x8b, 0x43 // It ls; bic ls r3 r3 r1
};
const byte kInstruction_bic_vc_r1_r1_r0[] = {
  0x78, 0xbf, 0x81, 0x43 // It vc; bic vc r1 r1 r0
};
const byte kInstruction_bic_ge_r2_r2_r0[] = {
  0xa8, 0xbf, 0x82, 0x43 // It ge; bic ge r2 r2 r0
};
const byte kInstruction_bic_ne_r5_r5_r7[] = {
  0x18, 0xbf, 0xbd, 0x43 // It ne; bic ne r5 r5 r7
};
const byte kInstruction_bic_hi_r3_r3_r0[] = {
  0x88, 0xbf, 0x83, 0x43 // It hi; bic hi r3 r3 r0
};
const byte kInstruction_bic_gt_r4_r4_r1[] = {
  0xc8, 0xbf, 0x8c, 0x43 // It gt; bic gt r4 r4 r1
};
const byte kInstruction_bic_hi_r6_r6_r7[] = {
  0x88, 0xbf, 0xbe, 0x43 // It hi; bic hi r6 r6 r7
};
const byte kInstruction_bic_cs_r6_r6_r2[] = {
  0x28, 0xbf, 0x96, 0x43 // It cs; bic cs r6 r6 r2
};
const byte kInstruction_bic_ne_r6_r6_r2[] = {
  0x18, 0xbf, 0x96, 0x43 // It ne; bic ne r6 r6 r2
};
const byte kInstruction_bic_le_r7_r7_r0[] = {
  0xd8, 0xbf, 0x87, 0x43 // It le; bic le r7 r7 r0
};
const byte kInstruction_bic_vs_r0_r0_r1[] = {
  0x68, 0xbf, 0x88, 0x43 // It vs; bic vs r0 r0 r1
};
const byte kInstruction_bic_vs_r4_r4_r2[] = {
  0x68, 0xbf, 0x94, 0x43 // It vs; bic vs r4 r4 r2
};
const byte kInstruction_bic_eq_r0_r0_r7[] = {
  0x08, 0xbf, 0xb8, 0x43 // It eq; bic eq r0 r0 r7
};
const byte kInstruction_bic_lt_r2_r2_r3[] = {
  0xb8, 0xbf, 0x9a, 0x43 // It lt; bic lt r2 r2 r3
};
const byte kInstruction_bic_ne_r5_r5_r4[] = {
  0x18, 0xbf, 0xa5, 0x43 // It ne; bic ne r5 r5 r4
};
const byte kInstruction_bic_cc_r4_r4_r5[] = {
  0x38, 0xbf, 0xac, 0x43 // It cc; bic cc r4 r4 r5
};
const byte kInstruction_bic_lt_r1_r1_r4[] = {
  0xb8, 0xbf, 0xa1, 0x43 // It lt; bic lt r1 r1 r4
};
const byte kInstruction_bic_eq_r0_r0_r0[] = {
  0x08, 0xbf, 0x80, 0x43 // It eq; bic eq r0 r0 r0
};
const byte kInstruction_bic_vs_r5_r5_r4[] = {
  0x68, 0xbf, 0xa5, 0x43 // It vs; bic vs r5 r5 r4
};
const byte kInstruction_bic_ne_r0_r0_r5[] = {
  0x18, 0xbf, 0xa8, 0x43 // It ne; bic ne r0 r0 r5
};
const byte kInstruction_bic_pl_r2_r2_r0[] = {
  0x58, 0xbf, 0x82, 0x43 // It pl; bic pl r2 r2 r0
};
const byte kInstruction_bic_vc_r2_r2_r5[] = {
  0x78, 0xbf, 0xaa, 0x43 // It vc; bic vc r2 r2 r5
};
const byte kInstruction_bic_lt_r3_r3_r1[] = {
  0xb8, 0xbf, 0x8b, 0x43 // It lt; bic lt r3 r3 r1
};
const byte kInstruction_bic_hi_r1_r1_r0[] = {
  0x88, 0xbf, 0x81, 0x43 // It hi; bic hi r1 r1 r0
};
const byte kInstruction_bic_eq_r4_r4_r6[] = {
  0x08, 0xbf, 0xb4, 0x43 // It eq; bic eq r4 r4 r6
};
const byte kInstruction_bic_vs_r3_r3_r6[] = {
  0x68, 0xbf, 0xb3, 0x43 // It vs; bic vs r3 r3 r6
};
const byte kInstruction_bic_lt_r1_r1_r0[] = {
  0xb8, 0xbf, 0x81, 0x43 // It lt; bic lt r1 r1 r0
};
const byte kInstruction_bic_ls_r2_r2_r2[] = {
  0x98, 0xbf, 0x92, 0x43 // It ls; bic ls r2 r2 r2
};
const byte kInstruction_bic_ge_r3_r3_r3[] = {
  0xa8, 0xbf, 0x9b, 0x43 // It ge; bic ge r3 r3 r3
};
const byte kInstruction_bic_ls_r2_r2_r7[] = {
  0x98, 0xbf, 0xba, 0x43 // It ls; bic ls r2 r2 r7
};
const byte kInstruction_bic_ge_r4_r4_r5[] = {
  0xa8, 0xbf, 0xac, 0x43 // It ge; bic ge r4 r4 r5
};
const byte kInstruction_bic_eq_r6_r6_r5[] = {
  0x08, 0xbf, 0xae, 0x43 // It eq; bic eq r6 r6 r5
};
const byte kInstruction_bic_mi_r2_r2_r3[] = {
  0x48, 0xbf, 0x9a, 0x43 // It mi; bic mi r2 r2 r3
};
const byte kInstruction_bic_mi_r7_r7_r6[] = {
  0x48, 0xbf, 0xb7, 0x43 // It mi; bic mi r7 r7 r6
};
const byte kInstruction_bic_ge_r2_r2_r3[] = {
  0xa8, 0xbf, 0x9a, 0x43 // It ge; bic ge r2 r2 r3
};
const byte kInstruction_bic_le_r5_r5_r1[] = {
  0xd8, 0xbf, 0x8d, 0x43 // It le; bic le r5 r5 r1
};
const byte kInstruction_bic_le_r7_r7_r5[] = {
  0xd8, 0xbf, 0xaf, 0x43 // It le; bic le r7 r7 r5
};
const byte kInstruction_bic_ne_r7_r7_r4[] = {
  0x18, 0xbf, 0xa7, 0x43 // It ne; bic ne r7 r7 r4
};
const byte kInstruction_bic_lt_r2_r2_r0[] = {
  0xb8, 0xbf, 0x82, 0x43 // It lt; bic lt r2 r2 r0
};
const byte kInstruction_bic_cs_r2_r2_r2[] = {
  0x28, 0xbf, 0x92, 0x43 // It cs; bic cs r2 r2 r2
};
const byte kInstruction_bic_hi_r5_r5_r1[] = {
  0x88, 0xbf, 0x8d, 0x43 // It hi; bic hi r5 r5 r1
};
const byte kInstruction_bic_cc_r5_r5_r2[] = {
  0x38, 0xbf, 0x95, 0x43 // It cc; bic cc r5 r5 r2
};
const byte kInstruction_bic_eq_r6_r6_r0[] = {
  0x08, 0xbf, 0x86, 0x43 // It eq; bic eq r6 r6 r0
};
const byte kInstruction_bic_hi_r5_r5_r5[] = {
  0x88, 0xbf, 0xad, 0x43 // It hi; bic hi r5 r5 r5
};
const byte kInstruction_bic_hi_r1_r1_r1[] = {
  0x88, 0xbf, 0x89, 0x43 // It hi; bic hi r1 r1 r1
};
const byte kInstruction_bic_eq_r3_r3_r7[] = {
  0x08, 0xbf, 0xbb, 0x43 // It eq; bic eq r3 r3 r7
};
const byte kInstruction_bic_lt_r0_r0_r3[] = {
  0xb8, 0xbf, 0x98, 0x43 // It lt; bic lt r0 r0 r3
};
const byte kInstruction_bic_ne_r7_r7_r0[] = {
  0x18, 0xbf, 0x87, 0x43 // It ne; bic ne r7 r7 r0
};
const byte kInstruction_bic_cs_r1_r1_r0[] = {
  0x28, 0xbf, 0x81, 0x43 // It cs; bic cs r1 r1 r0
};
const byte kInstruction_bic_le_r0_r0_r2[] = {
  0xd8, 0xbf, 0x90, 0x43 // It le; bic le r0 r0 r2
};
const byte kInstruction_bic_gt_r5_r5_r4[] = {
  0xc8, 0xbf, 0xa5, 0x43 // It gt; bic gt r5 r5 r4
};
const byte kInstruction_bic_le_r0_r0_r3[] = {
  0xd8, 0xbf, 0x98, 0x43 // It le; bic le r0 r0 r3
};
const byte kInstruction_bic_cs_r7_r7_r0[] = {
  0x28, 0xbf, 0x87, 0x43 // It cs; bic cs r7 r7 r0
};
const byte kInstruction_bic_eq_r7_r7_r2[] = {
  0x08, 0xbf, 0x97, 0x43 // It eq; bic eq r7 r7 r2
};
const byte kInstruction_bic_ne_r4_r4_r3[] = {
  0x18, 0xbf, 0x9c, 0x43 // It ne; bic ne r4 r4 r3
};
const byte kInstruction_bic_mi_r0_r0_r3[] = {
  0x48, 0xbf, 0x98, 0x43 // It mi; bic mi r0 r0 r3
};
const byte kInstruction_bic_cs_r4_r4_r0[] = {
  0x28, 0xbf, 0x84, 0x43 // It cs; bic cs r4 r4 r0
};
const byte kInstruction_bic_ls_r4_r4_r4[] = {
  0x98, 0xbf, 0xa4, 0x43 // It ls; bic ls r4 r4 r4
};
const byte kInstruction_bic_le_r3_r3_r6[] = {
  0xd8, 0xbf, 0xb3, 0x43 // It le; bic le r3 r3 r6
};
const byte kInstruction_bic_mi_r7_r7_r5[] = {
  0x48, 0xbf, 0xaf, 0x43 // It mi; bic mi r7 r7 r5
};
const byte kInstruction_bic_vs_r7_r7_r4[] = {
  0x68, 0xbf, 0xa7, 0x43 // It vs; bic vs r7 r7 r4
};
const byte kInstruction_bic_cc_r0_r0_r4[] = {
  0x38, 0xbf, 0xa0, 0x43 // It cc; bic cc r0 r0 r4
};
const byte kInstruction_bic_ls_r0_r0_r4[] = {
  0x98, 0xbf, 0xa0, 0x43 // It ls; bic ls r0 r0 r4
};
const byte kInstruction_bic_vs_r3_r3_r5[] = {
  0x68, 0xbf, 0xab, 0x43 // It vs; bic vs r3 r3 r5
};
const byte kInstruction_bic_lt_r7_r7_r5[] = {
  0xb8, 0xbf, 0xaf, 0x43 // It lt; bic lt r7 r7 r5
};
const byte kInstruction_bic_eq_r1_r1_r7[] = {
  0x08, 0xbf, 0xb9, 0x43 // It eq; bic eq r1 r1 r7
};
const byte kInstruction_bic_lt_r7_r7_r4[] = {
  0xb8, 0xbf, 0xa7, 0x43 // It lt; bic lt r7 r7 r4
};
const byte kInstruction_bic_cc_r3_r3_r5[] = {
  0x38, 0xbf, 0xab, 0x43 // It cc; bic cc r3 r3 r5
};
const byte kInstruction_bic_ge_r4_r4_r3[] = {
  0xa8, 0xbf, 0x9c, 0x43 // It ge; bic ge r4 r4 r3
};
const byte kInstruction_bic_cc_r4_r4_r6[] = {
  0x38, 0xbf, 0xb4, 0x43 // It cc; bic cc r4 r4 r6
};
const byte kInstruction_bic_hi_r3_r3_r6[] = {
  0x88, 0xbf, 0xb3, 0x43 // It hi; bic hi r3 r3 r6
};
const byte kInstruction_bic_gt_r0_r0_r6[] = {
  0xc8, 0xbf, 0xb0, 0x43 // It gt; bic gt r0 r0 r6
};
const byte kInstruction_bic_mi_r7_r7_r7[] = {
  0x48, 0xbf, 0xbf, 0x43 // It mi; bic mi r7 r7 r7
};
const byte kInstruction_bic_mi_r6_r6_r2[] = {
  0x48, 0xbf, 0x96, 0x43 // It mi; bic mi r6 r6 r2
};
const byte kInstruction_bic_ne_r1_r1_r5[] = {
  0x18, 0xbf, 0xa9, 0x43 // It ne; bic ne r1 r1 r5
};
const byte kInstruction_bic_gt_r1_r1_r2[] = {
  0xc8, 0xbf, 0x91, 0x43 // It gt; bic gt r1 r1 r2
};
const byte kInstruction_bic_lt_r7_r7_r2[] = {
  0xb8, 0xbf, 0x97, 0x43 // It lt; bic lt r7 r7 r2
};
const byte kInstruction_bic_cs_r5_r5_r5[] = {
  0x28, 0xbf, 0xad, 0x43 // It cs; bic cs r5 r5 r5
};
const byte kInstruction_bic_vc_r1_r1_r2[] = {
  0x78, 0xbf, 0x91, 0x43 // It vc; bic vc r1 r1 r2
};
const byte kInstruction_bic_eq_r5_r5_r6[] = {
  0x08, 0xbf, 0xb5, 0x43 // It eq; bic eq r5 r5 r6
};
const byte kInstruction_bic_vc_r5_r5_r2[] = {
  0x78, 0xbf, 0x95, 0x43 // It vc; bic vc r5 r5 r2
};
const byte kInstruction_bic_le_r6_r6_r2[] = {
  0xd8, 0xbf, 0x96, 0x43 // It le; bic le r6 r6 r2
};
const byte kInstruction_bic_le_r6_r6_r4[] = {
  0xd8, 0xbf, 0xa6, 0x43 // It le; bic le r6 r6 r4
};
const byte kInstruction_bic_pl_r3_r3_r2[] = {
  0x58, 0xbf, 0x93, 0x43 // It pl; bic pl r3 r3 r2
};
const byte kInstruction_bic_gt_r7_r7_r2[] = {
  0xc8, 0xbf, 0x97, 0x43 // It gt; bic gt r7 r7 r2
};
const byte kInstruction_bic_lt_r6_r6_r7[] = {
  0xb8, 0xbf, 0xbe, 0x43 // It lt; bic lt r6 r6 r7
};
const byte kInstruction_bic_gt_r4_r4_r7[] = {
  0xc8, 0xbf, 0xbc, 0x43 // It gt; bic gt r4 r4 r7
};
const byte kInstruction_bic_vc_r4_r4_r4[] = {
  0x78, 0xbf, 0xa4, 0x43 // It vc; bic vc r4 r4 r4
};
const byte kInstruction_bic_vc_r1_r1_r4[] = {
  0x78, 0xbf, 0xa1, 0x43 // It vc; bic vc r1 r1 r4
};
const byte kInstruction_bic_hi_r3_r3_r5[] = {
  0x88, 0xbf, 0xab, 0x43 // It hi; bic hi r3 r3 r5
};
const byte kInstruction_bic_gt_r3_r3_r2[] = {
  0xc8, 0xbf, 0x93, 0x43 // It gt; bic gt r3 r3 r2
};
const byte kInstruction_bic_ge_r5_r5_r7[] = {
  0xa8, 0xbf, 0xbd, 0x43 // It ge; bic ge r5 r5 r7
};
const byte kInstruction_bic_vs_r2_r2_r6[] = {
  0x68, 0xbf, 0xb2, 0x43 // It vs; bic vs r2 r2 r6
};
const byte kInstruction_bic_ge_r1_r1_r7[] = {
  0xa8, 0xbf, 0xb9, 0x43 // It ge; bic ge r1 r1 r7
};
const byte kInstruction_bic_ne_r6_r6_r1[] = {
  0x18, 0xbf, 0x8e, 0x43 // It ne; bic ne r6 r6 r1
};
const byte kInstruction_bic_eq_r6_r6_r1[] = {
  0x08, 0xbf, 0x8e, 0x43 // It eq; bic eq r6 r6 r1
};
const byte kInstruction_bic_lt_r1_r1_r6[] = {
  0xb8, 0xbf, 0xb1, 0x43 // It lt; bic lt r1 r1 r6
};
const byte kInstruction_bic_pl_r4_r4_r0[] = {
  0x58, 0xbf, 0x84, 0x43 // It pl; bic pl r4 r4 r0
};
const byte kInstruction_bic_mi_r3_r3_r0[] = {
  0x48, 0xbf, 0x83, 0x43 // It mi; bic mi r3 r3 r0
};
const byte kInstruction_bic_ne_r6_r6_r6[] = {
  0x18, 0xbf, 0xb6, 0x43 // It ne; bic ne r6 r6 r6
};
const byte kInstruction_bic_cs_r1_r1_r3[] = {
  0x28, 0xbf, 0x99, 0x43 // It cs; bic cs r1 r1 r3
};
const byte kInstruction_bic_gt_r7_r7_r6[] = {
  0xc8, 0xbf, 0xb7, 0x43 // It gt; bic gt r7 r7 r6
};
const byte kInstruction_bic_cc_r1_r1_r2[] = {
  0x38, 0xbf, 0x91, 0x43 // It cc; bic cc r1 r1 r2
};
const byte kInstruction_bic_vs_r0_r0_r4[] = {
  0x68, 0xbf, 0xa0, 0x43 // It vs; bic vs r0 r0 r4
};
const byte kInstruction_bic_ge_r0_r0_r5[] = {
  0xa8, 0xbf, 0xa8, 0x43 // It ge; bic ge r0 r0 r5
};
const byte kInstruction_bic_ls_r0_r0_r2[] = {
  0x98, 0xbf, 0x90, 0x43 // It ls; bic ls r0 r0 r2
};
const byte kInstruction_bic_lt_r0_r0_r6[] = {
  0xb8, 0xbf, 0xb0, 0x43 // It lt; bic lt r0 r0 r6
};
const byte kInstruction_bic_vc_r3_r3_r4[] = {
  0x78, 0xbf, 0xa3, 0x43 // It vc; bic vc r3 r3 r4
};
const byte kInstruction_bic_eq_r3_r3_r1[] = {
  0x08, 0xbf, 0x8b, 0x43 // It eq; bic eq r3 r3 r1
};
const byte kInstruction_bic_vc_r7_r7_r4[] = {
  0x78, 0xbf, 0xa7, 0x43 // It vc; bic vc r7 r7 r4
};
const byte kInstruction_bic_vs_r5_r5_r2[] = {
  0x68, 0xbf, 0x95, 0x43 // It vs; bic vs r5 r5 r2
};
const byte kInstruction_bic_cc_r2_r2_r6[] = {
  0x38, 0xbf, 0xb2, 0x43 // It cc; bic cc r2 r2 r6
};
const byte kInstruction_bic_cs_r0_r0_r7[] = {
  0x28, 0xbf, 0xb8, 0x43 // It cs; bic cs r0 r0 r7
};
const byte kInstruction_bic_vc_r3_r3_r1[] = {
  0x78, 0xbf, 0x8b, 0x43 // It vc; bic vc r3 r3 r1
};
const byte kInstruction_bic_cc_r6_r6_r1[] = {
  0x38, 0xbf, 0x8e, 0x43 // It cc; bic cc r6 r6 r1
};
const byte kInstruction_bic_gt_r4_r4_r0[] = {
  0xc8, 0xbf, 0x84, 0x43 // It gt; bic gt r4 r4 r0
};
const byte kInstruction_bic_mi_r4_r4_r3[] = {
  0x48, 0xbf, 0x9c, 0x43 // It mi; bic mi r4 r4 r3
};
const byte kInstruction_bic_ge_r4_r4_r2[] = {
  0xa8, 0xbf, 0x94, 0x43 // It ge; bic ge r4 r4 r2
};
const byte kInstruction_bic_vc_r2_r2_r1[] = {
  0x78, 0xbf, 0x8a, 0x43 // It vc; bic vc r2 r2 r1
};
const byte kInstruction_bic_mi_r0_r0_r6[] = {
  0x48, 0xbf, 0xb0, 0x43 // It mi; bic mi r0 r0 r6
};
const byte kInstruction_bic_gt_r4_r4_r6[] = {
  0xc8, 0xbf, 0xb4, 0x43 // It gt; bic gt r4 r4 r6
};
const byte kInstruction_bic_lt_r5_r5_r3[] = {
  0xb8, 0xbf, 0x9d, 0x43 // It lt; bic lt r5 r5 r3
};
const byte kInstruction_bic_hi_r0_r0_r3[] = {
  0x88, 0xbf, 0x98, 0x43 // It hi; bic hi r0 r0 r3
};
const byte kInstruction_bic_ne_r0_r0_r1[] = {
  0x18, 0xbf, 0x88, 0x43 // It ne; bic ne r0 r0 r1
};
const byte kInstruction_bic_ne_r4_r4_r4[] = {
  0x18, 0xbf, 0xa4, 0x43 // It ne; bic ne r4 r4 r4
};
const byte kInstruction_bic_vc_r3_r3_r7[] = {
  0x78, 0xbf, 0xbb, 0x43 // It vc; bic vc r3 r3 r7
};
const byte kInstruction_bic_eq_r2_r2_r4[] = {
  0x08, 0xbf, 0xa2, 0x43 // It eq; bic eq r2 r2 r4
};
const byte kInstruction_bic_ge_r6_r6_r5[] = {
  0xa8, 0xbf, 0xae, 0x43 // It ge; bic ge r6 r6 r5
};
const byte kInstruction_bic_vc_r6_r6_r2[] = {
  0x78, 0xbf, 0x96, 0x43 // It vc; bic vc r6 r6 r2
};
const byte kInstruction_bic_hi_r1_r1_r3[] = {
  0x88, 0xbf, 0x99, 0x43 // It hi; bic hi r1 r1 r3
};
const byte kInstruction_bic_pl_r0_r0_r4[] = {
  0x58, 0xbf, 0xa0, 0x43 // It pl; bic pl r0 r0 r4
};
const byte kInstruction_bic_vs_r1_r1_r6[] = {
  0x68, 0xbf, 0xb1, 0x43 // It vs; bic vs r1 r1 r6
};
const byte kInstruction_bic_cc_r1_r1_r4[] = {
  0x38, 0xbf, 0xa1, 0x43 // It cc; bic cc r1 r1 r4
};
const byte kInstruction_bic_lt_r1_r1_r3[] = {
  0xb8, 0xbf, 0x99, 0x43 // It lt; bic lt r1 r1 r3
};
const byte kInstruction_bic_pl_r1_r1_r4[] = {
  0x58, 0xbf, 0xa1, 0x43 // It pl; bic pl r1 r1 r4
};
const byte kInstruction_bic_cs_r3_r3_r3[] = {
  0x28, 0xbf, 0x9b, 0x43 // It cs; bic cs r3 r3 r3
};
const byte kInstruction_bic_ge_r7_r7_r0[] = {
  0xa8, 0xbf, 0x87, 0x43 // It ge; bic ge r7 r7 r0
};
const byte kInstruction_bic_ls_r5_r5_r1[] = {
  0x98, 0xbf, 0x8d, 0x43 // It ls; bic ls r5 r5 r1
};
const byte kInstruction_bic_pl_r7_r7_r3[] = {
  0x58, 0xbf, 0x9f, 0x43 // It pl; bic pl r7 r7 r3
};
const byte kInstruction_bic_eq_r2_r2_r1[] = {
  0x08, 0xbf, 0x8a, 0x43 // It eq; bic eq r2 r2 r1
};
const byte kInstruction_bic_mi_r4_r4_r5[] = {
  0x48, 0xbf, 0xac, 0x43 // It mi; bic mi r4 r4 r5
};
const byte kInstruction_bic_vc_r1_r1_r7[] = {
  0x78, 0xbf, 0xb9, 0x43 // It vc; bic vc r1 r1 r7
};
const byte kInstruction_bic_lt_r6_r6_r5[] = {
  0xb8, 0xbf, 0xae, 0x43 // It lt; bic lt r6 r6 r5
};
const byte kInstruction_bic_ge_r4_r4_r1[] = {
  0xa8, 0xbf, 0x8c, 0x43 // It ge; bic ge r4 r4 r1
};
const byte kInstruction_bic_gt_r1_r1_r7[] = {
  0xc8, 0xbf, 0xb9, 0x43 // It gt; bic gt r1 r1 r7
};
const byte kInstruction_bic_lt_r0_r0_r5[] = {
  0xb8, 0xbf, 0xa8, 0x43 // It lt; bic lt r0 r0 r5
};
const byte kInstruction_bic_le_r4_r4_r0[] = {
  0xd8, 0xbf, 0x84, 0x43 // It le; bic le r4 r4 r0
};
const byte kInstruction_bic_le_r1_r1_r3[] = {
  0xd8, 0xbf, 0x99, 0x43 // It le; bic le r1 r1 r3
};
const byte kInstruction_bic_cs_r6_r6_r0[] = {
  0x28, 0xbf, 0x86, 0x43 // It cs; bic cs r6 r6 r0
};
const TestResult kReferencebic[] = {
  {
    ARRAY_SIZE(kInstruction_bic_gt_r3_r3_r0),
    kInstruction_bic_gt_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r6_r6_r1),
    kInstruction_bic_ge_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r7_r7_r1),
    kInstruction_bic_gt_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r2_r2_r0),
    kInstruction_bic_gt_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r5_r5_r2),
    kInstruction_bic_eq_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r0_r0_r0),
    kInstruction_bic_gt_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r0_r0_r4),
    kInstruction_bic_lt_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r6_r6_r3),
    kInstruction_bic_hi_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r7_r7_r6),
    kInstruction_bic_ge_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r5_r5_r5),
    kInstruction_bic_eq_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r1_r1_r0),
    kInstruction_bic_cc_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r1_r1_r1),
    kInstruction_bic_cc_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r4_r4_r3),
    kInstruction_bic_cc_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r5_r5_r3),
    kInstruction_bic_mi_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r3_r3_r0),
    kInstruction_bic_cs_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r0_r0_r6),
    kInstruction_bic_pl_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r4_r4_r4),
    kInstruction_bic_cc_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r3_r3_r6),
    kInstruction_bic_cc_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r7_r7_r3),
    kInstruction_bic_hi_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r7_r7_r5),
    kInstruction_bic_vs_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r2_r2_r7),
    kInstruction_bic_le_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r5_r5_r3),
    kInstruction_bic_le_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r1_r1_r5),
    kInstruction_bic_vs_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r7_r7_r3),
    kInstruction_bic_vs_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r0_r0_r3),
    kInstruction_bic_cc_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r2_r2_r5),
    kInstruction_bic_cc_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r7_r7_r7),
    kInstruction_bic_gt_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r7_r7_r2),
    kInstruction_bic_ls_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r0_r0_r2),
    kInstruction_bic_lt_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r3_r3_r4),
    kInstruction_bic_ne_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r3_r3_r7),
    kInstruction_bic_ge_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r5_r5_r7),
    kInstruction_bic_hi_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r0_r0_r3),
    kInstruction_bic_vc_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r7_r7_r3),
    kInstruction_bic_cc_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r5_r5_r4),
    kInstruction_bic_ls_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r0_r0_r1),
    kInstruction_bic_vc_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r0_r0_r6),
    kInstruction_bic_hi_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r7_r7_r3),
    kInstruction_bic_mi_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r7_r7_r4),
    kInstruction_bic_cc_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r0_r0_r3),
    kInstruction_bic_pl_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r5_r5_r0),
    kInstruction_bic_ls_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r2_r2_r5),
    kInstruction_bic_ls_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r0_r0_r3),
    kInstruction_bic_ls_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r5_r5_r1),
    kInstruction_bic_pl_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r1_r1_r1),
    kInstruction_bic_mi_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r5_r5_r3),
    kInstruction_bic_ls_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r2_r2_r7),
    kInstruction_bic_gt_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r2_r2_r5),
    kInstruction_bic_ge_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r7_r7_r3),
    kInstruction_bic_gt_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r6_r6_r3),
    kInstruction_bic_vs_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r1_r1_r7),
    kInstruction_bic_cc_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r0_r0_r1),
    kInstruction_bic_ls_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r3_r3_r1),
    kInstruction_bic_gt_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r7_r7_r3),
    kInstruction_bic_cs_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r5_r5_r3),
    kInstruction_bic_gt_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r2_r2_r5),
    kInstruction_bic_le_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r1_r1_r0),
    kInstruction_bic_ne_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r7_r7_r7),
    kInstruction_bic_ne_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r2_r2_r1),
    kInstruction_bic_lt_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r3_r3_r1),
    kInstruction_bic_vs_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r7_r7_r5),
    kInstruction_bic_gt_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r6_r6_r1),
    kInstruction_bic_ls_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r7_r7_r4),
    kInstruction_bic_pl_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r6_r6_r7),
    kInstruction_bic_ls_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r5_r5_r3),
    kInstruction_bic_eq_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r2_r2_r7),
    kInstruction_bic_lt_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r7_r7_r6),
    kInstruction_bic_pl_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r1_r1_r6),
    kInstruction_bic_cs_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r0_r0_r3),
    kInstruction_bic_cs_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r3_r3_r2),
    kInstruction_bic_mi_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r4_r4_r5),
    kInstruction_bic_eq_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r3_r3_r4),
    kInstruction_bic_cs_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r7_r7_r6),
    kInstruction_bic_ls_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r0_r0_r7),
    kInstruction_bic_vs_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r2_r2_r1),
    kInstruction_bic_pl_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r0_r0_r5),
    kInstruction_bic_vs_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r4_r4_r2),
    kInstruction_bic_vc_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r4_r4_r7),
    kInstruction_bic_vc_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r4_r4_r7),
    kInstruction_bic_cs_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r5_r5_r2),
    kInstruction_bic_ne_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r1_r1_r5),
    kInstruction_bic_eq_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r0_r0_r7),
    kInstruction_bic_cc_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r4_r4_r0),
    kInstruction_bic_lt_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r2_r2_r6),
    kInstruction_bic_eq_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r2_r2_r1),
    kInstruction_bic_le_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r4_r4_r4),
    kInstruction_bic_mi_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r5_r5_r6),
    kInstruction_bic_ne_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r0_r0_r7),
    kInstruction_bic_gt_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r2_r2_r7),
    kInstruction_bic_hi_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r5_r5_r6),
    kInstruction_bic_vs_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r4_r4_r1),
    kInstruction_bic_eq_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r7_r7_r0),
    kInstruction_bic_eq_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r2_r2_r6),
    kInstruction_bic_ne_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r4_r4_r1),
    kInstruction_bic_vc_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r2_r2_r0),
    kInstruction_bic_le_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r5_r5_r5),
    kInstruction_bic_lt_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r3_r3_r7),
    kInstruction_bic_pl_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r1_r1_r5),
    kInstruction_bic_pl_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r3_r3_r1),
    kInstruction_bic_le_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r3_r3_r2),
    kInstruction_bic_vs_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r1_r1_r3),
    kInstruction_bic_pl_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r4_r4_r3),
    kInstruction_bic_le_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r6_r6_r1),
    kInstruction_bic_vs_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r1_r1_r1),
    kInstruction_bic_cs_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r2_r2_r6),
    kInstruction_bic_ge_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r0_r0_r0),
    kInstruction_bic_ls_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r5_r5_r1),
    kInstruction_bic_mi_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r4_r4_r1),
    kInstruction_bic_hi_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r3_r3_r2),
    kInstruction_bic_eq_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r5_r5_r1),
    kInstruction_bic_cc_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r6_r6_r2),
    kInstruction_bic_eq_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r4_r4_r2),
    kInstruction_bic_hi_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r5_r5_r0),
    kInstruction_bic_gt_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r3_r3_r2),
    kInstruction_bic_hi_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r0_r0_r0),
    kInstruction_bic_pl_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r3_r3_r7),
    kInstruction_bic_lt_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r7_r7_r1),
    kInstruction_bic_ls_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r3_r3_r3),
    kInstruction_bic_gt_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r6_r6_r6),
    kInstruction_bic_cs_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r3_r3_r2),
    kInstruction_bic_cc_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r4_r4_r0),
    kInstruction_bic_ne_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r4_r4_r5),
    kInstruction_bic_vs_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r6_r6_r4),
    kInstruction_bic_ge_r6_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r5_r5_r3),
    kInstruction_bic_ne_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r3_r3_r0),
    kInstruction_bic_vs_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r5_r5_r2),
    kInstruction_bic_lt_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r6_r6_r4),
    kInstruction_bic_lt_r6_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r2_r2_r5),
    kInstruction_bic_hi_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r7_r7_r5),
    kInstruction_bic_eq_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r4_r4_r5),
    kInstruction_bic_lt_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r7_r7_r3),
    kInstruction_bic_ls_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r3_r3_r5),
    kInstruction_bic_lt_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r5_r5_r0),
    kInstruction_bic_cs_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r2_r2_r3),
    kInstruction_bic_vc_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r1_r1_r4),
    kInstruction_bic_cs_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r5_r5_r4),
    kInstruction_bic_pl_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r7_r7_r4),
    kInstruction_bic_hi_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r3_r3_r6),
    kInstruction_bic_ge_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r3_r3_r2),
    kInstruction_bic_ls_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r3_r3_r3),
    kInstruction_bic_mi_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r6_r6_r5),
    kInstruction_bic_le_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r5_r5_r7),
    kInstruction_bic_pl_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r2_r2_r3),
    kInstruction_bic_ne_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r2_r2_r6),
    kInstruction_bic_ls_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r1_r1_r6),
    kInstruction_bic_le_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r6_r6_r7),
    kInstruction_bic_cc_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r4_r4_r3),
    kInstruction_bic_pl_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r0_r0_r3),
    kInstruction_bic_ne_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r6_r6_r6),
    kInstruction_bic_cc_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r7_r7_r5),
    kInstruction_bic_ls_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r1_r1_r5),
    kInstruction_bic_ls_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r0_r0_r0),
    kInstruction_bic_le_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r4_r4_r6),
    kInstruction_bic_ge_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r1_r1_r6),
    kInstruction_bic_cc_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r4_r4_r3),
    kInstruction_bic_eq_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r7_r7_r4),
    kInstruction_bic_ls_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r3_r3_r0),
    kInstruction_bic_eq_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r4_r4_r3),
    kInstruction_bic_lt_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r3_r3_r4),
    kInstruction_bic_le_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r4_r4_r4),
    kInstruction_bic_le_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r0_r0_r6),
    kInstruction_bic_ge_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r7_r7_r2),
    kInstruction_bic_hi_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r5_r5_r6),
    kInstruction_bic_pl_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r4_r4_r7),
    kInstruction_bic_pl_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r3_r3_r6),
    kInstruction_bic_gt_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r6_r6_r6),
    kInstruction_bic_eq_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r5_r5_r0),
    kInstruction_bic_cc_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r5_r5_r0),
    kInstruction_bic_hi_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r5_r5_r5),
    kInstruction_bic_gt_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r2_r2_r4),
    kInstruction_bic_vs_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r1_r1_r3),
    kInstruction_bic_vs_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r7_r7_r6),
    kInstruction_bic_lt_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r2_r2_r2),
    kInstruction_bic_ge_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r1_r1_r5),
    kInstruction_bic_mi_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r5_r5_r0),
    kInstruction_bic_ge_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r6_r6_r3),
    kInstruction_bic_le_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r7_r7_r5),
    kInstruction_bic_hi_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r3_r3_r4),
    kInstruction_bic_gt_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r3_r3_r3),
    kInstruction_bic_cc_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r2_r2_r2),
    kInstruction_bic_hi_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r7_r7_r3),
    kInstruction_bic_lt_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r6_r6_r6),
    kInstruction_bic_ls_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r7_r7_r7),
    kInstruction_bic_le_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r4_r4_r6),
    kInstruction_bic_cs_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r5_r5_r4),
    kInstruction_bic_ge_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r1_r1_r2),
    kInstruction_bic_ge_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r0_r0_r7),
    kInstruction_bic_pl_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r1_r1_r2),
    kInstruction_bic_vs_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r6_r6_r5),
    kInstruction_bic_mi_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r0_r0_r1),
    kInstruction_bic_mi_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r0_r0_r5),
    kInstruction_bic_vc_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r5_r5_r5),
    kInstruction_bic_cc_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r5_r5_r5),
    kInstruction_bic_pl_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r2_r2_r0),
    kInstruction_bic_ne_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r3_r3_r4),
    kInstruction_bic_cc_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r3_r3_r3),
    kInstruction_bic_ls_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r2_r2_r1),
    kInstruction_bic_cc_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r3_r3_r4),
    kInstruction_bic_ge_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r0_r0_r6),
    kInstruction_bic_ne_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r2_r2_r0),
    kInstruction_bic_vs_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r1_r1_r2),
    kInstruction_bic_ne_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r6_r6_r5),
    kInstruction_bic_ne_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r7_r7_r0),
    kInstruction_bic_pl_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r6_r6_r2),
    kInstruction_bic_pl_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r1_r1_r2),
    kInstruction_bic_pl_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r6_r6_r3),
    kInstruction_bic_gt_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r0_r0_r4),
    kInstruction_bic_vc_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r4_r4_r5),
    kInstruction_bic_vc_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r2_r2_r3),
    kInstruction_bic_vs_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r2_r2_r3),
    kInstruction_bic_pl_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r5_r5_r2),
    kInstruction_bic_hi_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r6_r6_r1),
    kInstruction_bic_le_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r3_r3_r0),
    kInstruction_bic_ne_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r7_r7_r1),
    kInstruction_bic_mi_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r7_r7_r7),
    kInstruction_bic_lt_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r5_r5_r7),
    kInstruction_bic_gt_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r1_r1_r1),
    kInstruction_bic_vc_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r1_r1_r2),
    kInstruction_bic_lt_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r6_r6_r6),
    kInstruction_bic_vs_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r5_r5_r5),
    kInstruction_bic_le_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r6_r6_r7),
    kInstruction_bic_gt_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r3_r3_r1),
    kInstruction_bic_cc_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r1_r1_r0),
    kInstruction_bic_ls_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r6_r6_r2),
    kInstruction_bic_vs_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r7_r7_r0),
    kInstruction_bic_mi_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r0_r0_r1),
    kInstruction_bic_gt_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r0_r0_r0),
    kInstruction_bic_ne_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r6_r6_r1),
    kInstruction_bic_lt_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r5_r5_r5),
    kInstruction_bic_ge_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r2_r2_r4),
    kInstruction_bic_lt_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r4_r4_r3),
    kInstruction_bic_vs_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r5_r5_r2),
    kInstruction_bic_cs_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r1_r1_r1),
    kInstruction_bic_gt_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r5_r5_r6),
    kInstruction_bic_cs_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r6_r6_r2),
    kInstruction_bic_gt_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r2_r2_r0),
    kInstruction_bic_cc_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r2_r2_r5),
    kInstruction_bic_lt_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r1_r1_r6),
    kInstruction_bic_mi_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r4_r4_r0),
    kInstruction_bic_hi_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r5_r5_r2),
    kInstruction_bic_le_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r5_r5_r7),
    kInstruction_bic_eq_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r5_r5_r0),
    kInstruction_bic_eq_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r0_r0_r1),
    kInstruction_bic_le_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r2_r2_r4),
    kInstruction_bic_cs_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r5_r5_r4),
    kInstruction_bic_cc_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r5_r5_r0),
    kInstruction_bic_mi_r5_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r1_r1_r0),
    kInstruction_bic_le_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r2_r2_r2),
    kInstruction_bic_mi_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r4_r4_r2),
    kInstruction_bic_ls_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r3_r3_r1),
    kInstruction_bic_ne_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r3_r3_r1),
    kInstruction_bic_hi_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r4_r4_r1),
    kInstruction_bic_pl_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r7_r7_r7),
    kInstruction_bic_pl_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r3_r3_r0),
    kInstruction_bic_ge_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r6_r6_r0),
    kInstruction_bic_vs_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r1_r1_r5),
    kInstruction_bic_gt_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r1_r1_r7),
    kInstruction_bic_ls_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r5_r5_r3),
    kInstruction_bic_hi_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r5_r5_r2),
    kInstruction_bic_ls_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r6_r6_r2),
    kInstruction_bic_ls_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r7_r7_r7),
    kInstruction_bic_cs_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r3_r3_r2),
    kInstruction_bic_le_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r6_r6_r0),
    kInstruction_bic_le_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r4_r4_r4),
    kInstruction_bic_pl_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r1_r1_r3),
    kInstruction_bic_ne_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r5_r5_r1),
    kInstruction_bic_ge_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r4_r4_r7),
    kInstruction_bic_eq_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r7_r7_r1),
    kInstruction_bic_pl_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r6_r6_r7),
    kInstruction_bic_vs_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r2_r2_r6),
    kInstruction_bic_vc_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r7_r7_r6),
    kInstruction_bic_hi_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r1_r1_r1),
    kInstruction_bic_le_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r4_r4_r1),
    kInstruction_bic_cs_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r1_r1_r2),
    kInstruction_bic_mi_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r3_r3_r5),
    kInstruction_bic_pl_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r7_r7_r1),
    kInstruction_bic_eq_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r0_r0_r5),
    kInstruction_bic_cs_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r3_r3_r5),
    kInstruction_bic_ge_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r6_r6_r3),
    kInstruction_bic_pl_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r7_r7_r5),
    kInstruction_bic_cc_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r4_r4_r6),
    kInstruction_bic_lt_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r7_r7_r2),
    kInstruction_bic_ne_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r3_r3_r0),
    kInstruction_bic_vc_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r7_r7_r6),
    kInstruction_bic_cc_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r0_r0_r0),
    kInstruction_bic_vc_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r7_r7_r3),
    kInstruction_bic_vc_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r7_r7_r0),
    kInstruction_bic_vs_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r2_r2_r0),
    kInstruction_bic_eq_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r2_r2_r1),
    kInstruction_bic_ne_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r7_r7_r2),
    kInstruction_bic_pl_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r3_r3_r6),
    kInstruction_bic_vc_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r5_r5_r1),
    kInstruction_bic_vs_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r2_r2_r2),
    kInstruction_bic_vs_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r6_r6_r6),
    kInstruction_bic_pl_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r6_r6_r3),
    kInstruction_bic_ge_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r2_r2_r6),
    kInstruction_bic_lt_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r5_r5_r6),
    kInstruction_bic_ls_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r7_r7_r6),
    kInstruction_bic_le_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r0_r0_r2),
    kInstruction_bic_ge_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r0_r0_r4),
    kInstruction_bic_le_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r6_r6_r3),
    kInstruction_bic_ls_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r6_r6_r0),
    kInstruction_bic_ls_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r4_r4_r7),
    kInstruction_bic_vs_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r4_r4_r4),
    kInstruction_bic_cs_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r7_r7_r5),
    kInstruction_bic_cs_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r6_r6_r3),
    kInstruction_bic_cs_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r7_r7_r4),
    kInstruction_bic_eq_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r6_r6_r0),
    kInstruction_bic_pl_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r5_r5_r4),
    kInstruction_bic_hi_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r6_r6_r6),
    kInstruction_bic_lt_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r7_r7_r2),
    kInstruction_bic_le_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r4_r4_r1),
    kInstruction_bic_le_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r4_r4_r6),
    kInstruction_bic_ne_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r0_r0_r1),
    kInstruction_bic_hi_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r6_r6_r5),
    kInstruction_bic_gt_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r5_r5_r6),
    kInstruction_bic_cc_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r3_r3_r4),
    kInstruction_bic_ls_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r6_r6_r6),
    kInstruction_bic_vc_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r4_r4_r2),
    kInstruction_bic_pl_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r6_r6_r3),
    kInstruction_bic_lt_r6_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r1_r1_r0),
    kInstruction_bic_mi_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r0_r0_r2),
    kInstruction_bic_cc_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r5_r5_r5),
    kInstruction_bic_ne_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r7_r7_r4),
    kInstruction_bic_cs_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r7_r7_r0),
    kInstruction_bic_vc_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r2_r2_r2),
    kInstruction_bic_cc_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r0_r0_r4),
    kInstruction_bic_ge_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r4_r4_r4),
    kInstruction_bic_gt_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r3_r3_r6),
    kInstruction_bic_cs_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r4_r4_r2),
    kInstruction_bic_cc_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r1_r1_r6),
    kInstruction_bic_eq_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r4_r4_r6),
    kInstruction_bic_mi_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r4_r4_r4),
    kInstruction_bic_eq_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r2_r2_r6),
    kInstruction_bic_gt_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r5_r5_r7),
    kInstruction_bic_lt_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r4_r4_r2),
    kInstruction_bic_lt_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r6_r6_r1),
    kInstruction_bic_cs_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r2_r2_r7),
    kInstruction_bic_vs_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r6_r6_r6),
    kInstruction_bic_hi_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r0_r0_r3),
    kInstruction_bic_vs_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r0_r0_r2),
    kInstruction_bic_mi_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r7_r7_r1),
    kInstruction_bic_cs_r7_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r1_r1_r6),
    kInstruction_bic_gt_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r3_r3_r7),
    kInstruction_bic_vs_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r1_r1_r5),
    kInstruction_bic_hi_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r4_r4_r1),
    kInstruction_bic_lt_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r6_r6_r6),
    kInstruction_bic_le_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r7_r7_r6),
    kInstruction_bic_vc_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r4_r4_r5),
    kInstruction_bic_gt_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r1_r1_r4),
    kInstruction_bic_le_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r2_r2_r1),
    kInstruction_bic_mi_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r3_r3_r1),
    kInstruction_bic_ls_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r1_r1_r0),
    kInstruction_bic_vc_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r2_r2_r0),
    kInstruction_bic_ge_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r5_r5_r7),
    kInstruction_bic_ne_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r3_r3_r0),
    kInstruction_bic_hi_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r4_r4_r1),
    kInstruction_bic_gt_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r6_r6_r7),
    kInstruction_bic_hi_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r6_r6_r2),
    kInstruction_bic_cs_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r6_r6_r2),
    kInstruction_bic_ne_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r7_r7_r0),
    kInstruction_bic_le_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r0_r0_r1),
    kInstruction_bic_vs_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r4_r4_r2),
    kInstruction_bic_vs_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r0_r0_r7),
    kInstruction_bic_eq_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r2_r2_r3),
    kInstruction_bic_lt_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r5_r5_r4),
    kInstruction_bic_ne_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r4_r4_r5),
    kInstruction_bic_cc_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r1_r1_r4),
    kInstruction_bic_lt_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r0_r0_r0),
    kInstruction_bic_eq_r0_r0_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r5_r5_r4),
    kInstruction_bic_vs_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r0_r0_r5),
    kInstruction_bic_ne_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r2_r2_r0),
    kInstruction_bic_pl_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r2_r2_r5),
    kInstruction_bic_vc_r2_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r3_r3_r1),
    kInstruction_bic_lt_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r1_r1_r0),
    kInstruction_bic_hi_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r4_r4_r6),
    kInstruction_bic_eq_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r3_r3_r6),
    kInstruction_bic_vs_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r1_r1_r0),
    kInstruction_bic_lt_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r2_r2_r2),
    kInstruction_bic_ls_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r3_r3_r3),
    kInstruction_bic_ge_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r2_r2_r7),
    kInstruction_bic_ls_r2_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r4_r4_r5),
    kInstruction_bic_ge_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r6_r6_r5),
    kInstruction_bic_eq_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r2_r2_r3),
    kInstruction_bic_mi_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r7_r7_r6),
    kInstruction_bic_mi_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r2_r2_r3),
    kInstruction_bic_ge_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r5_r5_r1),
    kInstruction_bic_le_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r7_r7_r5),
    kInstruction_bic_le_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r7_r7_r4),
    kInstruction_bic_ne_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r2_r2_r0),
    kInstruction_bic_lt_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r2_r2_r2),
    kInstruction_bic_cs_r2_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r5_r5_r1),
    kInstruction_bic_hi_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r5_r5_r2),
    kInstruction_bic_cc_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r6_r6_r0),
    kInstruction_bic_eq_r6_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r5_r5_r5),
    kInstruction_bic_hi_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r1_r1_r1),
    kInstruction_bic_hi_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r3_r3_r7),
    kInstruction_bic_eq_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r0_r0_r3),
    kInstruction_bic_lt_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r7_r7_r0),
    kInstruction_bic_ne_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r1_r1_r0),
    kInstruction_bic_cs_r1_r1_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r0_r0_r2),
    kInstruction_bic_le_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r5_r5_r4),
    kInstruction_bic_gt_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r0_r0_r3),
    kInstruction_bic_le_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r7_r7_r0),
    kInstruction_bic_cs_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r7_r7_r2),
    kInstruction_bic_eq_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r4_r4_r3),
    kInstruction_bic_ne_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r0_r0_r3),
    kInstruction_bic_mi_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r4_r4_r0),
    kInstruction_bic_cs_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r4_r4_r4),
    kInstruction_bic_ls_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r3_r3_r6),
    kInstruction_bic_le_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r7_r7_r5),
    kInstruction_bic_mi_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r7_r7_r4),
    kInstruction_bic_vs_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r0_r0_r4),
    kInstruction_bic_cc_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r0_r0_r4),
    kInstruction_bic_ls_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r3_r3_r5),
    kInstruction_bic_vs_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r7_r7_r5),
    kInstruction_bic_lt_r7_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r1_r1_r7),
    kInstruction_bic_eq_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r7_r7_r4),
    kInstruction_bic_lt_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r3_r3_r5),
    kInstruction_bic_cc_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r4_r4_r3),
    kInstruction_bic_ge_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r4_r4_r6),
    kInstruction_bic_cc_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r3_r3_r6),
    kInstruction_bic_hi_r3_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r0_r0_r6),
    kInstruction_bic_gt_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r7_r7_r7),
    kInstruction_bic_mi_r7_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r6_r6_r2),
    kInstruction_bic_mi_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r1_r1_r5),
    kInstruction_bic_ne_r1_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r1_r1_r2),
    kInstruction_bic_gt_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r7_r7_r2),
    kInstruction_bic_lt_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r5_r5_r5),
    kInstruction_bic_cs_r5_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r1_r1_r2),
    kInstruction_bic_vc_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r5_r5_r6),
    kInstruction_bic_eq_r5_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r5_r5_r2),
    kInstruction_bic_vc_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r6_r6_r2),
    kInstruction_bic_le_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r6_r6_r4),
    kInstruction_bic_le_r6_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r3_r3_r2),
    kInstruction_bic_pl_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r7_r7_r2),
    kInstruction_bic_gt_r7_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r6_r6_r7),
    kInstruction_bic_lt_r6_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r4_r4_r7),
    kInstruction_bic_gt_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r4_r4_r4),
    kInstruction_bic_vc_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r1_r1_r4),
    kInstruction_bic_vc_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r3_r3_r5),
    kInstruction_bic_hi_r3_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r3_r3_r2),
    kInstruction_bic_gt_r3_r3_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r5_r5_r7),
    kInstruction_bic_ge_r5_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r2_r2_r6),
    kInstruction_bic_vs_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r1_r1_r7),
    kInstruction_bic_ge_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r6_r6_r1),
    kInstruction_bic_ne_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r6_r6_r1),
    kInstruction_bic_eq_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r1_r1_r6),
    kInstruction_bic_lt_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r4_r4_r0),
    kInstruction_bic_pl_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r3_r3_r0),
    kInstruction_bic_mi_r3_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r6_r6_r6),
    kInstruction_bic_ne_r6_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r1_r1_r3),
    kInstruction_bic_cs_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r7_r7_r6),
    kInstruction_bic_gt_r7_r7_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r1_r1_r2),
    kInstruction_bic_cc_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r0_r0_r4),
    kInstruction_bic_vs_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r0_r0_r5),
    kInstruction_bic_ge_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r0_r0_r2),
    kInstruction_bic_ls_r0_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r0_r0_r6),
    kInstruction_bic_lt_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r3_r3_r4),
    kInstruction_bic_vc_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r3_r3_r1),
    kInstruction_bic_eq_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r7_r7_r4),
    kInstruction_bic_vc_r7_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r5_r5_r2),
    kInstruction_bic_vs_r5_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r2_r2_r6),
    kInstruction_bic_cc_r2_r2_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r0_r0_r7),
    kInstruction_bic_cs_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r3_r3_r1),
    kInstruction_bic_vc_r3_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r6_r6_r1),
    kInstruction_bic_cc_r6_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r4_r4_r0),
    kInstruction_bic_gt_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r4_r4_r3),
    kInstruction_bic_mi_r4_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r4_r4_r2),
    kInstruction_bic_ge_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r2_r2_r1),
    kInstruction_bic_vc_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r0_r0_r6),
    kInstruction_bic_mi_r0_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r4_r4_r6),
    kInstruction_bic_gt_r4_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r5_r5_r3),
    kInstruction_bic_lt_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r0_r0_r3),
    kInstruction_bic_hi_r0_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r0_r0_r1),
    kInstruction_bic_ne_r0_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ne_r4_r4_r4),
    kInstruction_bic_ne_r4_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r3_r3_r7),
    kInstruction_bic_vc_r3_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r2_r2_r4),
    kInstruction_bic_eq_r2_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r6_r6_r5),
    kInstruction_bic_ge_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r6_r6_r2),
    kInstruction_bic_vc_r6_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_bic_hi_r1_r1_r3),
    kInstruction_bic_hi_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r0_r0_r4),
    kInstruction_bic_pl_r0_r0_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vs_r1_r1_r6),
    kInstruction_bic_vs_r1_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cc_r1_r1_r4),
    kInstruction_bic_cc_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r1_r1_r3),
    kInstruction_bic_lt_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r1_r1_r4),
    kInstruction_bic_pl_r1_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r3_r3_r3),
    kInstruction_bic_cs_r3_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r7_r7_r0),
    kInstruction_bic_ge_r7_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ls_r5_r5_r1),
    kInstruction_bic_ls_r5_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_pl_r7_r7_r3),
    kInstruction_bic_pl_r7_r7_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_eq_r2_r2_r1),
    kInstruction_bic_eq_r2_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_mi_r4_r4_r5),
    kInstruction_bic_mi_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_vc_r1_r1_r7),
    kInstruction_bic_vc_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r6_r6_r5),
    kInstruction_bic_lt_r6_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_ge_r4_r4_r1),
    kInstruction_bic_ge_r4_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_bic_gt_r1_r1_r7),
    kInstruction_bic_gt_r1_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_bic_lt_r0_r0_r5),
    kInstruction_bic_lt_r0_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r4_r4_r0),
    kInstruction_bic_le_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_bic_le_r1_r1_r3),
    kInstruction_bic_le_r1_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_bic_cs_r6_r6_r0),
    kInstruction_bic_cs_r6_r6_r0,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_ALL_LOW_RD_IS_RN_IN_IT_BLOCK_BIC_T32_H_
